import typing

import android.app
import android.content
import android.location.provider
import android.os
import android.util
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class Address(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Address]] = ...
    def __init__(self, locale: java.util.Locale, /) -> None: ...
    def clearLatitude(self) -> None: ...
    def clearLongitude(self) -> None: ...
    def describeContents(self) -> int: ...
    def getAddressLine(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getAdminArea(self) -> str: ...
    def getCountryCode(self) -> str: ...
    def getCountryName(self) -> str: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFeatureName(self) -> str: ...
    def getLatitude(self) -> float: ...
    def getLocale(self) -> java.util.Locale: ...
    def getLocality(self) -> str: ...
    def getLongitude(self) -> float: ...
    def getMaxAddressLineIndex(self) -> int: ...
    def getPhone(self) -> str: ...
    def getPostalCode(self) -> str: ...
    def getPremises(self) -> str: ...
    def getSubAdminArea(self) -> str: ...
    def getSubLocality(self) -> str: ...
    def getSubThoroughfare(self) -> str: ...
    def getThoroughfare(self) -> str: ...
    def getUrl(self) -> str: ...
    def hasLatitude(self) -> bool: ...
    def hasLongitude(self) -> bool: ...
    def setAddressLine(self, index: int | java.jint | java.lang.Integer, line: str | java.lang.String, /) -> None: ...
    def setAdminArea(self, adminArea: str | java.lang.String, /) -> None: ...
    def setCountryCode(self, countryCode: str | java.lang.String, /) -> None: ...
    def setCountryName(self, countryName: str | java.lang.String, /) -> None: ...
    def setExtras(self, extras: android.os.Bundle, /) -> None: ...
    def setFeatureName(self, featureName: str | java.lang.String, /) -> None: ...
    def setLatitude(self, latitude: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setLocality(self, locality: str | java.lang.String, /) -> None: ...
    def setLongitude(self, longitude: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setPhone(self, phone: str | java.lang.String, /) -> None: ...
    def setPostalCode(self, postalCode: str | java.lang.String, /) -> None: ...
    def setPremises(self, premises: str | java.lang.String, /) -> None: ...
    def setSubAdminArea(self, subAdminArea: str | java.lang.String, /) -> None: ...
    def setSubLocality(self, sublocality: str | java.lang.String, /) -> None: ...
    def setSubThoroughfare(self, subthoroughfare: str | java.lang.String, /) -> None: ...
    def setThoroughfare(self, thoroughfare: str | java.lang.String, /) -> None: ...
    def setUrl(self, Url: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Criteria(android.os.Parcelable):
    ACCURACY_COARSE: typing.ClassVar[int] = ...
    ACCURACY_FINE: typing.ClassVar[int] = ...
    ACCURACY_HIGH: typing.ClassVar[int] = ...
    ACCURACY_LOW: typing.ClassVar[int] = ...
    ACCURACY_MEDIUM: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Criteria]] = ...
    NO_REQUIREMENT: typing.ClassVar[int] = ...
    POWER_HIGH: typing.ClassVar[int] = ...
    POWER_LOW: typing.ClassVar[int] = ...
    POWER_MEDIUM: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, criteria: Criteria, /) -> None: ...
    def describeContents(self) -> int: ...
    def getAccuracy(self) -> int: ...
    def getBearingAccuracy(self) -> int: ...
    def getHorizontalAccuracy(self) -> int: ...
    def getPowerRequirement(self) -> int: ...
    def getSpeedAccuracy(self) -> int: ...
    def getVerticalAccuracy(self) -> int: ...
    def isAltitudeRequired(self) -> bool: ...
    def isBearingRequired(self) -> bool: ...
    def isCostAllowed(self) -> bool: ...
    def isSpeedRequired(self) -> bool: ...
    def setAccuracy(self, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAltitudeRequired(self, altitudeRequired: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBearingAccuracy(self, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBearingRequired(self, bearingRequired: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCostAllowed(self, costAllowed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHorizontalAccuracy(self, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPowerRequirement(self, powerRequirement: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSpeedAccuracy(self, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSpeedRequired(self, speedRequired: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVerticalAccuracy(self, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Geocoder(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, locale: java.util.Locale, /) -> None: ...
    @typing.overload
    def getFromLocation(self, latitude: float | java.jdouble | java.lang.Double, longitude: float | java.jdouble | java.lang.Double, maxResults: int | java.jint | java.lang.Integer, /) -> java.util.List[Address] | None: ...
    @typing.overload
    def getFromLocation(self, latitude: float | java.jdouble | java.lang.Double, longitude: float | java.jdouble | java.lang.Double, maxResults: int | java.jint | java.lang.Integer, listener: Geocoder.GeocodeListener, /) -> None: ...
    @typing.overload
    def getFromLocationName(self, locationName: str | java.lang.String, maxResults: int | java.jint | java.lang.Integer, /) -> java.util.List[Address] | None: ...
    @typing.overload
    def getFromLocationName(self, locationName: str | java.lang.String, maxResults: int | java.jint | java.lang.Integer, listener: Geocoder.GeocodeListener, /) -> None: ...
    @typing.overload
    def getFromLocationName(self, locationName: str | java.lang.String, maxResults: int | java.jint | java.lang.Integer, lowerLeftLatitude: float | java.jdouble | java.lang.Double, lowerLeftLongitude: float | java.jdouble | java.lang.Double, upperRightLatitude: float | java.jdouble | java.lang.Double, upperRightLongitude: float | java.jdouble | java.lang.Double, /) -> java.util.List[Address] | None: ...
    @typing.overload
    def getFromLocationName(self, locationName: str | java.lang.String, maxResults: int | java.jint | java.lang.Integer, lowerLeftLatitude: float | java.jdouble | java.lang.Double, lowerLeftLongitude: float | java.jdouble | java.lang.Double, upperRightLatitude: float | java.jdouble | java.lang.Double, upperRightLongitude: float | java.jdouble | java.lang.Double, listener: Geocoder.GeocodeListener, /) -> None: ...
    @staticmethod
    def isPresent() -> bool: ...

    class GeocodeListener(java.lang.Object):
        def onError(self, errorMessage: str | java.lang.String, /) -> None: ...
        def onGeocode(self, arg1: java.util.List[Address], /) -> None: ...

class GnssAntennaInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssAntennaInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCarrierFrequencyMHz(self) -> float: ...
    def getPhaseCenterOffset(self) -> GnssAntennaInfo.PhaseCenterOffset: ...
    def getPhaseCenterVariationCorrections(self) -> GnssAntennaInfo.SphericalCorrections | None: ...
    def getSignalGainCorrections(self) -> GnssAntennaInfo.SphericalCorrections | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class SphericalCorrections(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssAntennaInfo.SphericalCorrections]] = ...
        def __init__(self, corrections: java.chaquopy.JavaArray[java.chaquopy.JavaArrayJDouble], correctionUncertainties: java.chaquopy.JavaArray[java.chaquopy.JavaArrayJDouble], /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getCorrectionUncertaintiesArray(self) -> java.chaquopy.JavaArray[java.chaquopy.JavaArrayJDouble]: ...
        def getCorrectionsArray(self) -> java.chaquopy.JavaArray[java.chaquopy.JavaArrayJDouble]: ...
        def getDeltaPhi(self) -> float: ...
        def getDeltaTheta(self) -> float: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class PhaseCenterOffset(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssAntennaInfo.PhaseCenterOffset]] = ...
        def __init__(self, offsetXMm: float | java.jdouble | java.lang.Double, offsetXUncertaintyMm: float | java.jdouble | java.lang.Double, offsetYMm: float | java.jdouble | java.lang.Double, offsetYUncertaintyMm: float | java.jdouble | java.lang.Double, offsetZMm: float | java.jdouble | java.lang.Double, offsetZUncertaintyMm: float | java.jdouble | java.lang.Double, /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getXOffsetMm(self) -> float: ...
        def getXOffsetUncertaintyMm(self) -> float: ...
        def getYOffsetMm(self) -> float: ...
        def getYOffsetUncertaintyMm(self) -> float: ...
        def getZOffsetMm(self) -> float: ...
        def getZOffsetUncertaintyMm(self) -> float: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Listener(java.lang.Object):
        def onGnssAntennaInfoReceived(self, arg1: java.util.List[GnssAntennaInfo], /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, antennaInfo: GnssAntennaInfo, /) -> None: ...
        @typing.overload
        def __init__(self, carrierFrequencyMHz: float | java.jdouble | java.lang.Double, phaseCenterOffset: GnssAntennaInfo.PhaseCenterOffset, /) -> None: ...
        def build(self) -> GnssAntennaInfo: ...
        def setCarrierFrequencyMHz(self, carrierFrequencyMHz: float | java.jdouble | java.lang.Double, /) -> GnssAntennaInfo.Builder: ...
        def setPhaseCenterOffset(self, phaseCenterOffset: GnssAntennaInfo.PhaseCenterOffset, /) -> GnssAntennaInfo.Builder: ...
        def setPhaseCenterVariationCorrections(self, phaseCenterVariationCorrections: GnssAntennaInfo.SphericalCorrections, /) -> GnssAntennaInfo.Builder: ...
        def setSignalGainCorrections(self, signalGainCorrections: GnssAntennaInfo.SphericalCorrections, /) -> GnssAntennaInfo.Builder: ...

class GnssAutomaticGainControl(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssAutomaticGainControl]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCarrierFrequencyHz(self) -> int: ...
    def getConstellationType(self) -> int: ...
    def getLevelDb(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flag: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, agc: GnssAutomaticGainControl, /) -> None: ...
        def build(self) -> GnssAutomaticGainControl: ...
        def setCarrierFrequencyHz(self, carrierFrequencyHz: int | java.jlong | java.lang.Long, /) -> GnssAutomaticGainControl.Builder: ...
        def setConstellationType(self, constellationType: int | java.jint | java.lang.Integer, /) -> GnssAutomaticGainControl.Builder: ...
        def setLevelDb(self, levelDb: float | java.jdouble | java.lang.Double, /) -> GnssAutomaticGainControl.Builder: ...

class GnssCapabilities(android.os.Parcelable):
    CAPABILITY_SUPPORTED: typing.ClassVar[int] = ...
    CAPABILITY_UNKNOWN: typing.ClassVar[int] = ...
    CAPABILITY_UNSUPPORTED: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssCapabilities]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getGnssSignalTypes(self) -> java.util.List[GnssSignalType]: ...
    def hasAccumulatedDeltaRange(self) -> int: ...
    def hasAntennaInfo(self) -> bool: ...
    def hasGeofencing(self) -> bool: ...
    def hasGnssAntennaInfo(self) -> bool: ...
    def hasLowPowerMode(self) -> bool: ...
    def hasMeasurementCorrections(self) -> bool: ...
    def hasMeasurementCorrectionsExcessPathLength(self) -> bool: ...
    def hasMeasurementCorrectionsForDriving(self) -> bool: ...
    def hasMeasurementCorrectionsLosSats(self) -> bool: ...
    def hasMeasurementCorrectionsReflectingPlane(self) -> bool: ...
    def hasMeasurementCorrelationVectors(self) -> bool: ...
    def hasMeasurements(self) -> bool: ...
    def hasMsa(self) -> bool: ...
    def hasMsb(self) -> bool: ...
    def hasNavigationMessages(self) -> bool: ...
    def hasOnDemandTime(self) -> bool: ...
    def hasPowerMultibandAcquisition(self) -> bool: ...
    def hasPowerMultibandTracking(self) -> bool: ...
    def hasPowerOtherModes(self) -> bool: ...
    def hasPowerSinglebandAcquisition(self) -> bool: ...
    def hasPowerSinglebandTracking(self) -> bool: ...
    def hasPowerTotal(self) -> bool: ...
    def hasSatelliteBlocklist(self) -> bool: ...
    def hasSatellitePvt(self) -> bool: ...
    def hasScheduling(self) -> bool: ...
    def hasSingleShotFix(self) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, capabilities: GnssCapabilities, /) -> None: ...
        def build(self) -> GnssCapabilities: ...
        def setGnssSignalTypes(self, gnssSignalTypes: java.util.List[GnssSignalType], /) -> GnssCapabilities.Builder: ...
        def setHasAccumulatedDeltaRange(self, capable: int | java.jint | java.lang.Integer, /) -> GnssCapabilities.Builder: ...
        def setHasAntennaInfo(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasGeofencing(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasLowPowerMode(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurementCorrections(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurementCorrectionsExcessPathLength(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurementCorrectionsForDriving(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurementCorrectionsLosSats(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurementCorrectionsReflectingPlane(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurementCorrelationVectors(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMeasurements(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMsa(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasMsb(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasNavigationMessages(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasOnDemandTime(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasPowerMultibandAcquisition(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasPowerMultibandTracking(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasPowerOtherModes(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasPowerSinglebandAcquisition(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasPowerSinglebandTracking(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasPowerTotal(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasSatelliteBlocklist(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasSatellitePvt(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasScheduling(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...
        def setHasSingleShotFix(self, capable: bool | java.jboolean | java.lang.Boolean, /) -> GnssCapabilities.Builder: ...

class GnssClock(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssClock]] = ...
    def describeContents(self) -> int: ...
    def getBiasNanos(self) -> float: ...
    def getBiasUncertaintyNanos(self) -> float: ...
    def getDriftNanosPerSecond(self) -> float: ...
    def getDriftUncertaintyNanosPerSecond(self) -> float: ...
    def getElapsedRealtimeNanos(self) -> int: ...
    def getElapsedRealtimeUncertaintyNanos(self) -> float: ...
    def getFullBiasNanos(self) -> int: ...
    def getHardwareClockDiscontinuityCount(self) -> int: ...
    def getLeapSecond(self) -> int: ...
    def getReferenceCarrierFrequencyHzForIsb(self) -> float: ...
    def getReferenceCodeTypeForIsb(self) -> str: ...
    def getReferenceConstellationTypeForIsb(self) -> int: ...
    def getTimeNanos(self) -> int: ...
    def getTimeUncertaintyNanos(self) -> float: ...
    def hasBiasNanos(self) -> bool: ...
    def hasBiasUncertaintyNanos(self) -> bool: ...
    def hasDriftNanosPerSecond(self) -> bool: ...
    def hasDriftUncertaintyNanosPerSecond(self) -> bool: ...
    def hasElapsedRealtimeNanos(self) -> bool: ...
    def hasElapsedRealtimeUncertaintyNanos(self) -> bool: ...
    def hasFullBiasNanos(self) -> bool: ...
    def hasLeapSecond(self) -> bool: ...
    def hasReferenceCarrierFrequencyHzForIsb(self) -> bool: ...
    def hasReferenceCodeTypeForIsb(self) -> bool: ...
    def hasReferenceConstellationTypeForIsb(self) -> bool: ...
    def hasTimeUncertaintyNanos(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class GnssMeasurement(android.os.Parcelable):
    ADR_STATE_CYCLE_SLIP: typing.ClassVar[int] = ...
    ADR_STATE_HALF_CYCLE_REPORTED: typing.ClassVar[int] = ...
    ADR_STATE_HALF_CYCLE_RESOLVED: typing.ClassVar[int] = ...
    ADR_STATE_RESET: typing.ClassVar[int] = ...
    ADR_STATE_UNKNOWN: typing.ClassVar[int] = ...
    ADR_STATE_VALID: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssMeasurement]] = ...
    MULTIPATH_INDICATOR_DETECTED: typing.ClassVar[int] = ...
    MULTIPATH_INDICATOR_NOT_DETECTED: typing.ClassVar[int] = ...
    MULTIPATH_INDICATOR_UNKNOWN: typing.ClassVar[int] = ...
    STATE_2ND_CODE_LOCK: typing.ClassVar[int] = ...
    STATE_BDS_D2_BIT_SYNC: typing.ClassVar[int] = ...
    STATE_BDS_D2_SUBFRAME_SYNC: typing.ClassVar[int] = ...
    STATE_BIT_SYNC: typing.ClassVar[int] = ...
    STATE_CODE_LOCK: typing.ClassVar[int] = ...
    STATE_GAL_E1BC_CODE_LOCK: typing.ClassVar[int] = ...
    STATE_GAL_E1B_PAGE_SYNC: typing.ClassVar[int] = ...
    STATE_GAL_E1C_2ND_CODE_LOCK: typing.ClassVar[int] = ...
    STATE_GLO_STRING_SYNC: typing.ClassVar[int] = ...
    STATE_GLO_TOD_DECODED: typing.ClassVar[int] = ...
    STATE_GLO_TOD_KNOWN: typing.ClassVar[int] = ...
    STATE_MSEC_AMBIGUOUS: typing.ClassVar[int] = ...
    STATE_SBAS_SYNC: typing.ClassVar[int] = ...
    STATE_SUBFRAME_SYNC: typing.ClassVar[int] = ...
    STATE_SYMBOL_SYNC: typing.ClassVar[int] = ...
    STATE_TOW_DECODED: typing.ClassVar[int] = ...
    STATE_TOW_KNOWN: typing.ClassVar[int] = ...
    STATE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getAccumulatedDeltaRangeMeters(self) -> float: ...
    def getAccumulatedDeltaRangeState(self) -> int: ...
    def getAccumulatedDeltaRangeUncertaintyMeters(self) -> float: ...
    def getAutomaticGainControlLevelDb(self) -> float: ...
    def getBasebandCn0DbHz(self) -> float: ...
    def getCarrierCycles(self) -> int: ...
    def getCarrierFrequencyHz(self) -> float: ...
    def getCarrierPhase(self) -> float: ...
    def getCarrierPhaseUncertainty(self) -> float: ...
    def getCn0DbHz(self) -> float: ...
    def getCodeType(self) -> str: ...
    def getConstellationType(self) -> int: ...
    def getFullInterSignalBiasNanos(self) -> float: ...
    def getFullInterSignalBiasUncertaintyNanos(self) -> float: ...
    def getMultipathIndicator(self) -> int: ...
    def getPseudorangeRateMetersPerSecond(self) -> float: ...
    def getPseudorangeRateUncertaintyMetersPerSecond(self) -> float: ...
    def getReceivedSvTimeNanos(self) -> int: ...
    def getReceivedSvTimeUncertaintyNanos(self) -> int: ...
    def getSatelliteInterSignalBiasNanos(self) -> float: ...
    def getSatelliteInterSignalBiasUncertaintyNanos(self) -> float: ...
    def getSnrInDb(self) -> float: ...
    def getState(self) -> int: ...
    def getSvid(self) -> int: ...
    def getTimeOffsetNanos(self) -> float: ...
    def hasAutomaticGainControlLevelDb(self) -> bool: ...
    def hasBasebandCn0DbHz(self) -> bool: ...
    def hasCarrierCycles(self) -> bool: ...
    def hasCarrierFrequencyHz(self) -> bool: ...
    def hasCarrierPhase(self) -> bool: ...
    def hasCarrierPhaseUncertainty(self) -> bool: ...
    def hasCodeType(self) -> bool: ...
    def hasFullInterSignalBiasNanos(self) -> bool: ...
    def hasFullInterSignalBiasUncertaintyNanos(self) -> bool: ...
    def hasSatelliteInterSignalBiasNanos(self) -> bool: ...
    def hasSatelliteInterSignalBiasUncertaintyNanos(self) -> bool: ...
    def hasSnrInDb(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class GnssMeasurementRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssMeasurementRequest]] = ...
    PASSIVE_INTERVAL: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIntervalMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def isFullTracking(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, request: GnssMeasurementRequest, /) -> None: ...
        def build(self) -> GnssMeasurementRequest: ...
        def setFullTracking(self, value: bool | java.jboolean | java.lang.Boolean, /) -> GnssMeasurementRequest.Builder: ...
        def setIntervalMillis(self, value: int | java.jint | java.lang.Integer, /) -> GnssMeasurementRequest.Builder: ...

class GnssMeasurementsEvent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssMeasurementsEvent]] = ...
    def describeContents(self) -> int: ...
    def getClock(self) -> GnssClock: ...
    def getGnssAutomaticGainControls(self) -> java.util.Collection[GnssAutomaticGainControl]: ...
    def getMeasurements(self) -> java.util.Collection[GnssMeasurement]: ...
    def hasIsFullTracking(self) -> bool: ...
    def isFullTracking(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback(java.lang.Object):
        STATUS_LOCATION_DISABLED: typing.ClassVar[int] = ...
        STATUS_NOT_ALLOWED: typing.ClassVar[int] = ...
        STATUS_NOT_SUPPORTED: typing.ClassVar[int] = ...
        STATUS_READY: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def onGnssMeasurementsReceived(self, eventArgs: GnssMeasurementsEvent, /) -> None: ...
        def onStatusChanged(self, status: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, event: GnssMeasurementsEvent, /) -> None: ...
        def build(self) -> GnssMeasurementsEvent: ...
        def clearIsFullTracking(self) -> GnssMeasurementsEvent.Builder: ...
        def setClock(self, clock: GnssClock, /) -> GnssMeasurementsEvent.Builder: ...
        def setGnssAutomaticGainControls(self, agcs: java.util.Collection[GnssAutomaticGainControl], /) -> GnssMeasurementsEvent.Builder: ...
        def setIsFullTracking(self, isFullTracking: bool | java.jboolean | java.lang.Boolean, /) -> GnssMeasurementsEvent.Builder: ...
        def setMeasurements(self, measurements: java.util.Collection[GnssMeasurement], /) -> GnssMeasurementsEvent.Builder: ...

class GnssNavigationMessage(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssNavigationMessage]] = ...
    STATUS_PARITY_PASSED: typing.ClassVar[int] = ...
    STATUS_PARITY_REBUILT: typing.ClassVar[int] = ...
    STATUS_UNKNOWN: typing.ClassVar[int] = ...
    TYPE_BDS_CNAV1: typing.ClassVar[int] = ...
    TYPE_BDS_CNAV2: typing.ClassVar[int] = ...
    TYPE_BDS_D1: typing.ClassVar[int] = ...
    TYPE_BDS_D2: typing.ClassVar[int] = ...
    TYPE_GAL_F: typing.ClassVar[int] = ...
    TYPE_GAL_I: typing.ClassVar[int] = ...
    TYPE_GLO_L1CA: typing.ClassVar[int] = ...
    TYPE_GPS_CNAV2: typing.ClassVar[int] = ...
    TYPE_GPS_L1CA: typing.ClassVar[int] = ...
    TYPE_GPS_L2CNAV: typing.ClassVar[int] = ...
    TYPE_GPS_L5CNAV: typing.ClassVar[int] = ...
    TYPE_IRN_L1: typing.ClassVar[int] = ...
    TYPE_IRN_L5: typing.ClassVar[int] = ...
    TYPE_IRN_L5CA: typing.ClassVar[int] = ...
    TYPE_QZS_L1CA: typing.ClassVar[int] = ...
    TYPE_SBS: typing.ClassVar[int] = ...
    TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMessageId(self) -> int: ...
    def getStatus(self) -> int: ...
    def getSubmessageId(self) -> int: ...
    def getSvid(self) -> int: ...
    def getType(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback(java.lang.Object):
        STATUS_LOCATION_DISABLED: typing.ClassVar[int] = ...
        STATUS_NOT_SUPPORTED: typing.ClassVar[int] = ...
        STATUS_READY: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def onGnssNavigationMessageReceived(self, event: GnssNavigationMessage, /) -> None: ...
        def onStatusChanged(self, status: int | java.jint | java.lang.Integer, /) -> None: ...

class GnssSignalType(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssSignalType]] = ...
    @staticmethod
    def create(constellationType: int | java.jint | java.lang.Integer, carrierFrequencyHz: float | java.jdouble | java.lang.Double, codeType: str | java.lang.String, /) -> GnssSignalType: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCarrierFrequencyHz(self) -> float: ...
    def getCodeType(self) -> str: ...
    def getConstellationType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class GnssStatus(android.os.Parcelable):
    CONSTELLATION_BEIDOU: typing.ClassVar[int] = ...
    CONSTELLATION_GALILEO: typing.ClassVar[int] = ...
    CONSTELLATION_GLONASS: typing.ClassVar[int] = ...
    CONSTELLATION_GPS: typing.ClassVar[int] = ...
    CONSTELLATION_IRNSS: typing.ClassVar[int] = ...
    CONSTELLATION_QZSS: typing.ClassVar[int] = ...
    CONSTELLATION_SBAS: typing.ClassVar[int] = ...
    CONSTELLATION_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GnssStatus]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAzimuthDegrees(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getBasebandCn0DbHz(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getCarrierFrequencyHz(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getCn0DbHz(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getConstellationType(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getElevationDegrees(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getSatelliteCount(self) -> int: ...
    def getSvid(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def hasAlmanacData(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasBasebandCn0DbHz(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasCarrierFrequencyHz(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasEphemerisData(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hashCode(self) -> int: ...
    def usedInFix(self, satelliteIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onFirstFix(self, ttffMillis: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSatelliteStatusChanged(self, status: GnssStatus, /) -> None: ...
        def onStarted(self) -> None: ...
        def onStopped(self) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addSatellite(self, constellationType: int | java.jint | java.lang.Integer, svid: int | java.jint | java.lang.Integer, cn0DbHz: float | java.jfloat | java.lang.Float, elevation: float | java.jfloat | java.lang.Float, azimuth: float | java.jfloat | java.lang.Float, hasEphemeris: bool | java.jboolean | java.lang.Boolean, hasAlmanac: bool | java.jboolean | java.lang.Boolean, usedInFix: bool | java.jboolean | java.lang.Boolean, hasCarrierFrequency: bool | java.jboolean | java.lang.Boolean, carrierFrequency: float | java.jfloat | java.lang.Float, hasBasebandCn0DbHz: bool | java.jboolean | java.lang.Boolean, basebandCn0DbHz: float | java.jfloat | java.lang.Float, /) -> GnssStatus.Builder: ...
        def build(self) -> GnssStatus: ...
        def clearSatellites(self) -> GnssStatus.Builder: ...

class GpsSatellite(java.lang.Object):
    def getAzimuth(self) -> float: ...
    def getElevation(self) -> float: ...
    def getPrn(self) -> int: ...
    def getSnr(self) -> float: ...
    def hasAlmanac(self) -> bool: ...
    def hasEphemeris(self) -> bool: ...
    def usedInFix(self) -> bool: ...

class GpsStatus(java.lang.Object):
    GPS_EVENT_FIRST_FIX: typing.ClassVar[int] = ...
    GPS_EVENT_SATELLITE_STATUS: typing.ClassVar[int] = ...
    GPS_EVENT_STARTED: typing.ClassVar[int] = ...
    GPS_EVENT_STOPPED: typing.ClassVar[int] = ...
    @staticmethod
    def create(gnssStatus: GnssStatus, timeToFirstFix: int | java.jint | java.lang.Integer, /) -> GpsStatus: ...
    def getMaxSatellites(self) -> int: ...
    def getSatellites(self) -> java.lang.Iterable[GpsSatellite]: ...
    def getTimeToFirstFix(self) -> int: ...

    class NmeaListener(java.lang.Object):
        def onNmeaReceived(self, arg1: int | java.jlong | java.lang.Long, arg2: str | java.lang.String, /) -> None: ...

    class Listener(java.lang.Object):
        def onGpsStatusChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class Location(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Location]] = ...
    FORMAT_DEGREES: typing.ClassVar[int] = ...
    FORMAT_MINUTES: typing.ClassVar[int] = ...
    FORMAT_SECONDS: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, location: Location, /) -> None: ...
    @typing.overload
    def __init__(self, provider: str | java.lang.String, /) -> None: ...
    def bearingTo(self, dest: Location, /) -> float: ...
    @typing.overload
    @staticmethod
    def convert(coordinate: str | java.lang.String, /) -> float: ...
    @typing.overload
    @staticmethod
    def convert(coordinate: float | java.jdouble | java.lang.Double, outputType: int | java.jint | java.lang.Integer, /) -> str: ...
    def describeContents(self) -> int: ...
    @staticmethod
    def distanceBetween(startLatitude: float | java.jdouble | java.lang.Double, startLongitude: float | java.jdouble | java.lang.Double, endLatitude: float | java.jdouble | java.lang.Double, endLongitude: float | java.jdouble | java.lang.Double, results: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def distanceTo(self, dest: Location, /) -> float: ...
    def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAccuracy(self) -> float: ...
    def getAltitude(self) -> float: ...
    def getBearing(self) -> float: ...
    def getBearingAccuracyDegrees(self) -> float: ...
    @typing.overload
    def getElapsedRealtimeAgeMillis(self) -> int: ...
    @typing.overload
    def getElapsedRealtimeAgeMillis(self, referenceRealtimeMs: int | java.jlong | java.lang.Long, /) -> int: ...
    def getElapsedRealtimeMillis(self) -> int: ...
    def getElapsedRealtimeNanos(self) -> int: ...
    def getElapsedRealtimeUncertaintyNanos(self) -> float: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getLatitude(self) -> float: ...
    def getLongitude(self) -> float: ...
    def getMslAltitudeAccuracyMeters(self) -> float: ...
    def getMslAltitudeMeters(self) -> float: ...
    def getProvider(self) -> str | None: ...
    def getSpeed(self) -> float: ...
    def getSpeedAccuracyMetersPerSecond(self) -> float: ...
    def getTime(self) -> int: ...
    def getVerticalAccuracyMeters(self) -> float: ...
    def hasAccuracy(self) -> bool: ...
    def hasAltitude(self) -> bool: ...
    def hasBearing(self) -> bool: ...
    def hasBearingAccuracy(self) -> bool: ...
    def hasElapsedRealtimeUncertaintyNanos(self) -> bool: ...
    def hasMslAltitude(self) -> bool: ...
    def hasMslAltitudeAccuracy(self) -> bool: ...
    def hasSpeed(self) -> bool: ...
    def hasSpeedAccuracy(self) -> bool: ...
    def hasVerticalAccuracy(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isComplete(self) -> bool: ...
    def isFromMockProvider(self) -> bool: ...
    def isMock(self) -> bool: ...
    def removeAccuracy(self) -> None: ...
    def removeAltitude(self) -> None: ...
    def removeBearing(self) -> None: ...
    def removeBearingAccuracy(self) -> None: ...
    def removeElapsedRealtimeUncertaintyNanos(self) -> None: ...
    def removeMslAltitude(self) -> None: ...
    def removeMslAltitudeAccuracy(self) -> None: ...
    def removeSpeed(self) -> None: ...
    def removeSpeedAccuracy(self) -> None: ...
    def removeVerticalAccuracy(self) -> None: ...
    def reset(self) -> None: ...
    def set(self, location: Location, /) -> None: ...
    def setAccuracy(self, horizontalAccuracyMeters: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setAltitude(self, altitudeMeters: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setBearing(self, bearingDegrees: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setBearingAccuracyDegrees(self, bearingAccuracyDegrees: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setElapsedRealtimeNanos(self, elapsedRealtimeNs: int | java.jlong | java.lang.Long, /) -> None: ...
    def setElapsedRealtimeUncertaintyNanos(self, elapsedRealtimeUncertaintyNs: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setExtras(self, extras: android.os.Bundle, /) -> None: ...
    def setLatitude(self, latitudeDegrees: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setLongitude(self, longitudeDegrees: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setMock(self, mock: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMslAltitudeAccuracyMeters(self, mslAltitudeAccuracyMeters: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setMslAltitudeMeters(self, mslAltitudeMeters: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setProvider(self, provider: str | java.lang.String, /) -> None: ...
    def setSpeed(self, speedMetersPerSecond: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setSpeedAccuracyMetersPerSecond(self, speedAccuracyMeterPerSecond: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTime(self, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def setVerticalAccuracyMeters(self, altitudeAccuracyMeters: float | java.jfloat | java.lang.Float, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LocationListener(java.lang.Object):
    def onFlushComplete(self, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onLocationChanged(self, arg1: Location, /) -> None: ...
    @typing.overload
    def onLocationChanged(self, locations: java.util.List[Location], /) -> None: ...
    def onProviderDisabled(self, provider: str | java.lang.String, /) -> None: ...
    def onProviderEnabled(self, provider: str | java.lang.String, /) -> None: ...
    def onStatusChanged(self, provider: str | java.lang.String, status: int | java.jint | java.lang.Integer, extras: android.os.Bundle, /) -> None: ...

class LocationManager(java.lang.Object):
    ACTION_GNSS_CAPABILITIES_CHANGED: typing.ClassVar[str] = ...
    EXTRA_GNSS_CAPABILITIES: typing.ClassVar[str] = ...
    EXTRA_LOCATION_ENABLED: typing.ClassVar[str] = ...
    EXTRA_PROVIDER_ENABLED: typing.ClassVar[str] = ...
    EXTRA_PROVIDER_NAME: typing.ClassVar[str] = ...
    FUSED_PROVIDER: typing.ClassVar[str] = ...
    GPS_PROVIDER: typing.ClassVar[str] = ...
    KEY_FLUSH_COMPLETE: typing.ClassVar[str] = ...
    KEY_LOCATIONS: typing.ClassVar[str] = ...
    KEY_LOCATION_CHANGED: typing.ClassVar[str] = ...
    KEY_PROVIDER_ENABLED: typing.ClassVar[str] = ...
    KEY_PROXIMITY_ENTERING: typing.ClassVar[str] = ...
    KEY_STATUS_CHANGED: typing.ClassVar[str] = ...
    MODE_CHANGED_ACTION: typing.ClassVar[str] = ...
    NETWORK_PROVIDER: typing.ClassVar[str] = ...
    PASSIVE_PROVIDER: typing.ClassVar[str] = ...
    PROVIDERS_CHANGED_ACTION: typing.ClassVar[str] = ...
    def addGpsStatusListener(self, listener: GpsStatus.Listener, /) -> bool: ...
    @typing.overload
    def addNmeaListener(self, listener: GpsStatus.NmeaListener, /) -> bool: ...
    @typing.overload
    def addNmeaListener(self, listener: OnNmeaMessageListener, /) -> bool: ...
    @typing.overload
    def addNmeaListener(self, listener: OnNmeaMessageListener, handler: android.os.Handler, /) -> bool: ...
    @typing.overload
    def addNmeaListener(self, executor: java.util.concurrent.Executor, listener: OnNmeaMessageListener, /) -> bool: ...
    def addProximityAlert(self, latitude: float | java.jdouble | java.lang.Double, longitude: float | java.jdouble | java.lang.Double, radius: float | java.jfloat | java.lang.Float, expiration: int | java.jlong | java.lang.Long, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def addTestProvider(self, provider: str | java.lang.String, properties: android.location.provider.ProviderProperties, /) -> None: ...
    @typing.overload
    def addTestProvider(self, provider: str | java.lang.String, properties: android.location.provider.ProviderProperties, extraAttributionTags: java.util.Set[java.lang.String], /) -> None: ...
    @typing.overload
    def addTestProvider(self, provider: str | java.lang.String, requiresNetwork: bool | java.jboolean | java.lang.Boolean, requiresSatellite: bool | java.jboolean | java.lang.Boolean, requiresCell: bool | java.jboolean | java.lang.Boolean, hasMonetaryCost: bool | java.jboolean | java.lang.Boolean, supportsAltitude: bool | java.jboolean | java.lang.Boolean, supportsSpeed: bool | java.jboolean | java.lang.Boolean, supportsBearing: bool | java.jboolean | java.lang.Boolean, powerUsage: int | java.jint | java.lang.Integer, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearTestProviderEnabled(self, provider: str | java.lang.String, /) -> None: ...
    def clearTestProviderLocation(self, provider: str | java.lang.String, /) -> None: ...
    def clearTestProviderStatus(self, provider: str | java.lang.String, /) -> None: ...
    def getAllProviders(self) -> java.util.List[java.lang.String]: ...
    def getBestProvider(self, criteria: Criteria, enabledOnly: bool | java.jboolean | java.lang.Boolean, /) -> str | None: ...
    @typing.overload
    def getCurrentLocation(self, provider: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, consumer: java.util.function.Consumer[Location], /) -> None: ...
    @typing.overload
    def getCurrentLocation(self, provider: str | java.lang.String, locationRequest: LocationRequest, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, consumer: java.util.function.Consumer[Location], /) -> None: ...
    def getGnssAntennaInfos(self) -> java.util.List[GnssAntennaInfo] | None: ...
    def getGnssCapabilities(self) -> GnssCapabilities: ...
    def getGnssHardwareModelName(self) -> str | None: ...
    def getGnssYearOfHardware(self) -> int: ...
    def getGpsStatus(self, status: GpsStatus, /) -> GpsStatus | None: ...
    def getLastKnownLocation(self, provider: str | java.lang.String, /) -> Location | None: ...
    def getProvider(self, provider: str | java.lang.String, /) -> LocationProvider | None: ...
    def getProviderProperties(self, provider: str | java.lang.String, /) -> android.location.provider.ProviderProperties | None: ...
    @typing.overload
    def getProviders(self, enabledOnly: bool | java.jboolean | java.lang.Boolean, /) -> java.util.List[java.lang.String]: ...
    @typing.overload
    def getProviders(self, criteria: Criteria, enabledOnly: bool | java.jboolean | java.lang.Boolean, /) -> java.util.List[java.lang.String]: ...
    def hasProvider(self, provider: str | java.lang.String, /) -> bool: ...
    def isLocationEnabled(self) -> bool: ...
    def isProviderEnabled(self, provider: str | java.lang.String, /) -> bool: ...
    def registerAntennaInfoListener(self, executor: java.util.concurrent.Executor, listener: GnssAntennaInfo.Listener, /) -> bool: ...
    @typing.overload
    def registerGnssMeasurementsCallback(self, callback: GnssMeasurementsEvent.Callback, /) -> bool: ...
    @typing.overload
    def registerGnssMeasurementsCallback(self, callback: GnssMeasurementsEvent.Callback, handler: android.os.Handler, /) -> bool: ...
    @typing.overload
    def registerGnssMeasurementsCallback(self, executor: java.util.concurrent.Executor, callback: GnssMeasurementsEvent.Callback, /) -> bool: ...
    @typing.overload
    def registerGnssMeasurementsCallback(self, request: GnssMeasurementRequest, executor: java.util.concurrent.Executor, callback: GnssMeasurementsEvent.Callback, /) -> bool: ...
    @typing.overload
    def registerGnssNavigationMessageCallback(self, callback: GnssNavigationMessage.Callback, /) -> bool: ...
    @typing.overload
    def registerGnssNavigationMessageCallback(self, callback: GnssNavigationMessage.Callback, handler: android.os.Handler, /) -> bool: ...
    @typing.overload
    def registerGnssNavigationMessageCallback(self, executor: java.util.concurrent.Executor, callback: GnssNavigationMessage.Callback, /) -> bool: ...
    @typing.overload
    def registerGnssStatusCallback(self, callback: GnssStatus.Callback, /) -> bool: ...
    @typing.overload
    def registerGnssStatusCallback(self, callback: GnssStatus.Callback, handler: android.os.Handler, /) -> bool: ...
    @typing.overload
    def registerGnssStatusCallback(self, executor: java.util.concurrent.Executor, callback: GnssStatus.Callback, /) -> bool: ...
    def removeGpsStatusListener(self, listener: GpsStatus.Listener, /) -> None: ...
    @typing.overload
    def removeNmeaListener(self, listener: GpsStatus.NmeaListener, /) -> None: ...
    @typing.overload
    def removeNmeaListener(self, listener: OnNmeaMessageListener, /) -> None: ...
    def removeProximityAlert(self, intent: android.app.PendingIntent, /) -> None: ...
    def removeTestProvider(self, provider: str | java.lang.String, /) -> None: ...
    @typing.overload
    def removeUpdates(self, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def removeUpdates(self, listener: LocationListener, /) -> None: ...
    @typing.overload
    def requestFlush(self, provider: str | java.lang.String, pendingIntent: android.app.PendingIntent, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def requestFlush(self, provider: str | java.lang.String, listener: LocationListener, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, provider: str | java.lang.String, locationRequest: LocationRequest, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, criteria: Criteria, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, provider: str | java.lang.String, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, provider: str | java.lang.String, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, listener: LocationListener, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, provider: str | java.lang.String, locationRequest: LocationRequest, executor: java.util.concurrent.Executor, listener: LocationListener, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, criteria: Criteria, listener: LocationListener, looper: android.os.Looper, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, criteria: Criteria, executor: java.util.concurrent.Executor, listener: LocationListener, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, provider: str | java.lang.String, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, listener: LocationListener, looper: android.os.Looper, /) -> None: ...
    @typing.overload
    def requestLocationUpdates(self, provider: str | java.lang.String, minTimeMs: int | java.jlong | java.lang.Long, minDistanceM: float | java.jfloat | java.lang.Float, executor: java.util.concurrent.Executor, listener: LocationListener, /) -> None: ...
    @typing.overload
    def requestSingleUpdate(self, criteria: Criteria, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def requestSingleUpdate(self, provider: str | java.lang.String, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def requestSingleUpdate(self, criteria: Criteria, listener: LocationListener, looper: android.os.Looper, /) -> None: ...
    @typing.overload
    def requestSingleUpdate(self, provider: str | java.lang.String, listener: LocationListener, looper: android.os.Looper, /) -> None: ...
    def sendExtraCommand(self, provider: str | java.lang.String, command: str | java.lang.String, extras: android.os.Bundle, /) -> bool: ...
    def setTestProviderEnabled(self, provider: str | java.lang.String, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTestProviderLocation(self, provider: str | java.lang.String, location: Location, /) -> None: ...
    def setTestProviderStatus(self, provider: str | java.lang.String, status: int | java.jint | java.lang.Integer, extras: android.os.Bundle, updateTime: int | java.jlong | java.lang.Long, /) -> None: ...
    def unregisterAntennaInfoListener(self, listener: GnssAntennaInfo.Listener, /) -> None: ...
    def unregisterGnssMeasurementsCallback(self, callback: GnssMeasurementsEvent.Callback, /) -> None: ...
    def unregisterGnssNavigationMessageCallback(self, callback: GnssNavigationMessage.Callback, /) -> None: ...
    def unregisterGnssStatusCallback(self, callback: GnssStatus.Callback, /) -> None: ...

class LocationProvider(java.lang.Object):
    AVAILABLE: typing.ClassVar[int] = ...
    OUT_OF_SERVICE: typing.ClassVar[int] = ...
    TEMPORARILY_UNAVAILABLE: typing.ClassVar[int] = ...
    def getAccuracy(self) -> int: ...
    def getName(self) -> str: ...
    def getPowerRequirement(self) -> int: ...
    def hasMonetaryCost(self) -> bool: ...
    def meetsCriteria(self, criteria: Criteria, /) -> bool: ...
    def requiresCell(self) -> bool: ...
    def requiresNetwork(self) -> bool: ...
    def requiresSatellite(self) -> bool: ...
    def supportsAltitude(self) -> bool: ...
    def supportsBearing(self) -> bool: ...
    def supportsSpeed(self) -> bool: ...

class LocationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LocationRequest]] = ...
    PASSIVE_INTERVAL: typing.ClassVar[int] = ...
    QUALITY_BALANCED_POWER_ACCURACY: typing.ClassVar[int] = ...
    QUALITY_HIGH_ACCURACY: typing.ClassVar[int] = ...
    QUALITY_LOW_POWER: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDurationMillis(self) -> int: ...
    def getIntervalMillis(self) -> int: ...
    def getMaxUpdateDelayMillis(self) -> int: ...
    def getMaxUpdates(self) -> int: ...
    def getMinUpdateDistanceMeters(self) -> float: ...
    def getMinUpdateIntervalMillis(self) -> int: ...
    def getQuality(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, intervalMillis: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def __init__(self, locationRequest: LocationRequest, /) -> None: ...
        def build(self) -> LocationRequest: ...
        def clearMinUpdateIntervalMillis(self) -> LocationRequest.Builder: ...
        def setDurationMillis(self, durationMillis: int | java.jlong | java.lang.Long, /) -> LocationRequest.Builder: ...
        def setIntervalMillis(self, intervalMillis: int | java.jlong | java.lang.Long, /) -> LocationRequest.Builder: ...
        def setMaxUpdateDelayMillis(self, maxUpdateDelayMillis: int | java.jlong | java.lang.Long, /) -> LocationRequest.Builder: ...
        def setMaxUpdates(self, maxUpdates: int | java.jint | java.lang.Integer, /) -> LocationRequest.Builder: ...
        def setMinUpdateDistanceMeters(self, minUpdateDistanceMeters: float | java.jfloat | java.lang.Float, /) -> LocationRequest.Builder: ...
        def setMinUpdateIntervalMillis(self, minUpdateIntervalMillis: int | java.jlong | java.lang.Long, /) -> LocationRequest.Builder: ...
        def setQuality(self, quality: int | java.jint | java.lang.Integer, /) -> LocationRequest.Builder: ...

class OnNmeaMessageListener(java.lang.Object):
    def onNmeaMessage(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> None: ...

class SettingInjectorService(android.app.Service):
    ACTION_INJECTED_SETTING_CHANGED: typing.ClassVar[str] = ...
    ACTION_SERVICE_INTENT: typing.ClassVar[str] = ...
    ATTRIBUTES_NAME: typing.ClassVar[str] = ...
    META_DATA_NAME: typing.ClassVar[str] = ...
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onGetEnabled(self) -> bool: ...
    def onGetSummary(self) -> str: ...
    def onStart(self, intent: android.content.Intent, startId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartCommand(self, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, startId: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def refreshSettings(context: android.content.Context, /) -> None: ...



import typing

class Primitive:
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...

class jvoid(Primitive):
    def __init__(self) -> None: ...

class jboolean(Primitive):
    value: bool
    def __init__(self, value: typing.Any) -> None: ...

class NumericPrimitive(Primitive): ...

class IntPrimitive(NumericPrimitive):
    value: int
    def __init__(self, value: int, truncate: bool = False) -> None: ...

class jbyte(IntPrimitive): ...
class jshort(IntPrimitive): ...
class jint(IntPrimitive): ...
class jlong(IntPrimitive): ...

class FloatPrimitive(NumericPrimitive):
    value: float
    def __init__(self, value: float | int, truncate: bool = False) -> None: ...

class jfloat(FloatPrimitive): ...
class jdouble(FloatPrimitive): ...

class jchar(Primitive):
    value: str
    def __init__(self, value: str) -> None: ...



import typing

import android.app
import android.content
import android.content.pm
import android.graphics
import android.graphics.drawable
import android.os
import android.util
import android.view
import android.widget
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class AppWidgetHost(java.lang.Object):
    def __init__(self, context: android.content.Context, hostId: int | java.jint | java.lang.Integer, /) -> None: ...
    def allocateAppWidgetId(self) -> int: ...
    def clearViews(self) -> None: ...
    def createView(self, context: android.content.Context, appWidgetId: int | java.jint | java.lang.Integer, appWidget: AppWidgetProviderInfo, /) -> AppWidgetHostView: ...
    @staticmethod
    def deleteAllHosts() -> None: ...
    def deleteAppWidgetId(self, appWidgetId: int | java.jint | java.lang.Integer, /) -> None: ...
    def deleteHost(self) -> None: ...
    def getAppWidgetIds(self) -> java.chaquopy.JavaArrayJInt: ...
    def onAppWidgetRemoved(self, appWidgetId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onCreateView(self, context: android.content.Context, appWidgetId: int | java.jint | java.lang.Integer, appWidget: AppWidgetProviderInfo, /) -> AppWidgetHostView: ...
    def onProviderChanged(self, appWidgetId: int | java.jint | java.lang.Integer, appWidget: AppWidgetProviderInfo, /) -> None: ...
    def onProvidersChanged(self) -> None: ...
    def startAppWidgetConfigureActivityForResult(self, activity: android.app.Activity, appWidgetId: int | java.jint | java.lang.Integer, intentFlags: int | java.jint | java.lang.Integer, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def startListening(self) -> None: ...
    def stopListening(self) -> None: ...

class AppWidgetHostView(android.widget.FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, animationIn: int | java.jint | java.lang.Integer, animationOut: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchRestoreInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchSaveInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> android.widget.FrameLayout.LayoutParams: ...
    def getAppWidgetId(self) -> int: ...
    def getAppWidgetInfo(self) -> AppWidgetProviderInfo: ...
    @staticmethod
    def getDefaultPaddingForWidget(context: android.content.Context, component: android.content.ComponentName, padding: android.graphics.Rect, /) -> android.graphics.Rect: ...
    def getDefaultView(self) -> android.view.View: ...
    def getErrorView(self) -> android.view.View: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def prepareView(self, view: android.view.View, /) -> None: ...
    def resetColorResources(self) -> None: ...
    def setAppWidget(self, appWidgetId: int | java.jint | java.lang.Integer, info: AppWidgetProviderInfo, /) -> None: ...
    def setColorResources(self, colorMapping: android.util.SparseIntArray, /) -> None: ...
    def setExecutor(self, executor: java.util.concurrent.Executor, /) -> None: ...
    def setOnLightBackground(self, onLightBackground: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def updateAppWidget(self, remoteViews: android.widget.RemoteViews, /) -> None: ...
    def updateAppWidgetOptions(self, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def updateAppWidgetSize(self, newOptions: android.os.Bundle, sizes: java.util.List[android.util.SizeF], /) -> None: ...
    @typing.overload
    def updateAppWidgetSize(self, newOptions: android.os.Bundle, minWidth: int | java.jint | java.lang.Integer, minHeight: int | java.jint | java.lang.Integer, maxWidth: int | java.jint | java.lang.Integer, maxHeight: int | java.jint | java.lang.Integer, /) -> None: ...

class AppWidgetManager(java.lang.Object):
    ACTION_APPWIDGET_BIND: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_CONFIGURE: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_DELETED: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_DISABLED: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_ENABLED: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_HOST_RESTORED: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_OPTIONS_CHANGED: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_PICK: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_RESTORED: typing.ClassVar[str] = ...
    ACTION_APPWIDGET_UPDATE: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_ID: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_IDS: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_OLD_IDS: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_OPTIONS: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_PREVIEW: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_PROVIDER: typing.ClassVar[str] = ...
    EXTRA_APPWIDGET_PROVIDER_PROFILE: typing.ClassVar[str] = ...
    EXTRA_CUSTOM_EXTRAS: typing.ClassVar[str] = ...
    EXTRA_CUSTOM_INFO: typing.ClassVar[str] = ...
    EXTRA_HOST_ID: typing.ClassVar[str] = ...
    INVALID_APPWIDGET_ID: typing.ClassVar[int] = ...
    META_DATA_APPWIDGET_PROVIDER: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_HOST_CATEGORY: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_MAX_HEIGHT: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_MAX_WIDTH: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_MIN_HEIGHT: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_MIN_WIDTH: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_RESTORE_COMPLETED: typing.ClassVar[str] = ...
    OPTION_APPWIDGET_SIZES: typing.ClassVar[str] = ...
    @typing.overload
    def bindAppWidgetIdIfAllowed(self, appWidgetId: int | java.jint | java.lang.Integer, provider: android.content.ComponentName, /) -> bool: ...
    @typing.overload
    def bindAppWidgetIdIfAllowed(self, appWidgetId: int | java.jint | java.lang.Integer, provider: android.content.ComponentName, options: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def bindAppWidgetIdIfAllowed(self, appWidgetId: int | java.jint | java.lang.Integer, user: android.os.UserHandle, provider: android.content.ComponentName, options: android.os.Bundle, /) -> bool: ...
    def getAppWidgetIds(self, provider: android.content.ComponentName, /) -> java.chaquopy.JavaArrayJInt: ...
    def getAppWidgetInfo(self, appWidgetId: int | java.jint | java.lang.Integer, /) -> AppWidgetProviderInfo | None: ...
    def getAppWidgetOptions(self, appWidgetId: int | java.jint | java.lang.Integer, /) -> android.os.Bundle: ...
    def getInstalledProviders(self) -> java.util.List[AppWidgetProviderInfo]: ...
    def getInstalledProvidersForPackage(self, packageName: str | java.lang.String, profile: android.os.UserHandle, /) -> java.util.List[AppWidgetProviderInfo]: ...
    def getInstalledProvidersForProfile(self, profile: android.os.UserHandle, /) -> java.util.List[AppWidgetProviderInfo]: ...
    @staticmethod
    def getInstance(context: android.content.Context, /) -> AppWidgetManager: ...
    def getWidgetPreview(self, provider: android.content.ComponentName, profile: android.os.UserHandle, widgetCategory: int | java.jint | java.lang.Integer, /) -> android.widget.RemoteViews | None: ...
    def isRequestPinAppWidgetSupported(self) -> bool: ...
    @typing.overload
    def notifyAppWidgetViewDataChanged(self, appWidgetId: int | java.jint | java.lang.Integer, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def notifyAppWidgetViewDataChanged(self, appWidgetIds: java.chaquopy.JavaArrayJInt, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def partiallyUpdateAppWidget(self, appWidgetId: int | java.jint | java.lang.Integer, views: android.widget.RemoteViews, /) -> None: ...
    @typing.overload
    def partiallyUpdateAppWidget(self, appWidgetIds: java.chaquopy.JavaArrayJInt, views: android.widget.RemoteViews, /) -> None: ...
    def removeWidgetPreview(self, provider: android.content.ComponentName, widgetCategories: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestPinAppWidget(self, provider: android.content.ComponentName, extras: android.os.Bundle, successCallback: android.app.PendingIntent, /) -> bool: ...
    def setWidgetPreview(self, provider: android.content.ComponentName, widgetCategories: int | java.jint | java.lang.Integer, preview: android.widget.RemoteViews, /) -> bool: ...
    @typing.overload
    def updateAppWidget(self, appWidgetId: int | java.jint | java.lang.Integer, views: android.widget.RemoteViews, /) -> None: ...
    @typing.overload
    def updateAppWidget(self, provider: android.content.ComponentName, views: android.widget.RemoteViews, /) -> None: ...
    @typing.overload
    def updateAppWidget(self, appWidgetIds: java.chaquopy.JavaArrayJInt, views: android.widget.RemoteViews, /) -> None: ...
    def updateAppWidgetOptions(self, appWidgetId: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def updateAppWidgetProviderInfo(self, provider: android.content.ComponentName, metaDataKey: str | java.lang.String, /) -> None: ...

class AppWidgetProvider(android.content.BroadcastReceiver):
    def __init__(self) -> None: ...
    def onAppWidgetOptionsChanged(self, context: android.content.Context, appWidgetManager: AppWidgetManager, appWidgetId: int | java.jint | java.lang.Integer, newOptions: android.os.Bundle, /) -> None: ...
    def onDeleted(self, context: android.content.Context, appWidgetIds: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def onDisabled(self, context: android.content.Context, /) -> None: ...
    def onEnabled(self, context: android.content.Context, /) -> None: ...
    def onReceive(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onRestored(self, context: android.content.Context, oldWidgetIds: java.chaquopy.JavaArrayJInt, newWidgetIds: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def onUpdate(self, context: android.content.Context, appWidgetManager: AppWidgetManager, appWidgetIds: java.chaquopy.JavaArrayJInt, /) -> None: ...

class AppWidgetProviderInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppWidgetProviderInfo]] = ...
    RESIZE_BOTH: typing.ClassVar[int] = ...
    RESIZE_HORIZONTAL: typing.ClassVar[int] = ...
    RESIZE_NONE: typing.ClassVar[int] = ...
    RESIZE_VERTICAL: typing.ClassVar[int] = ...
    WIDGET_CATEGORY_HOME_SCREEN: typing.ClassVar[int] = ...
    WIDGET_CATEGORY_KEYGUARD: typing.ClassVar[int] = ...
    WIDGET_CATEGORY_NOT_KEYGUARD: typing.ClassVar[int] = ...
    WIDGET_CATEGORY_SEARCHBOX: typing.ClassVar[int] = ...
    WIDGET_FEATURE_CONFIGURATION_OPTIONAL: typing.ClassVar[int] = ...
    WIDGET_FEATURE_HIDE_FROM_PICKER: typing.ClassVar[int] = ...
    WIDGET_FEATURE_RECONFIGURABLE: typing.ClassVar[int] = ...
    autoAdvanceViewId: int = ...
    configure: android.content.ComponentName = ...
    descriptionRes: int = ...
    generatedPreviewCategories: int = ...
    icon: int = ...
    initialKeyguardLayout: int = ...
    initialLayout: int = ...
    label: str = ...
    maxResizeHeight: int = ...
    maxResizeWidth: int = ...
    minHeight: int = ...
    minResizeHeight: int = ...
    minResizeWidth: int = ...
    minWidth: int = ...
    previewImage: int = ...
    previewLayout: int = ...
    provider: android.content.ComponentName = ...
    resizeMode: int = ...
    targetCellHeight: int = ...
    targetCellWidth: int = ...
    updatePeriodMillis: int = ...
    widgetCategory: int = ...
    widgetFeatures: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    def clone(self) -> AppWidgetProviderInfo: ...
    def describeContents(self) -> int: ...
    def getActivityInfo(self) -> android.content.pm.ActivityInfo: ...
    def getProfile(self) -> android.os.UserHandle: ...
    def loadDescription(self, context: android.content.Context, /) -> java.lang.CharSequence | None: ...
    def loadIcon(self, context: android.content.Context, density: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
    def loadLabel(self, packageManager: android.content.pm.PackageManager, /) -> str: ...
    def loadPreviewImage(self, context: android.content.Context, density: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java.lang

class AdServicesException(java.lang.Exception):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, e: java.lang.Throwable, /) -> None: ...



import typing

import android.os
import java
import java.lang
import java.util

class BleCsRangingCapabilities(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BleCsRangingCapabilities]] = ...
    CS_SECURITY_LEVEL_FOUR: typing.ClassVar[int] = ...
    CS_SECURITY_LEVEL_ONE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getSupportedSecurityLevels(self) -> java.util.Set[java.lang.Integer]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BleCsRangingParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BleCsRangingParams]] = ...
    LOCATION_TYPE_INDOOR: typing.ClassVar[int] = ...
    LOCATION_TYPE_OUTDOOR: typing.ClassVar[int] = ...
    LOCATION_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    SIGHT_TYPE_LINE_OF_SIGHT: typing.ClassVar[int] = ...
    SIGHT_TYPE_NON_LINE_OF_SIGHT: typing.ClassVar[int] = ...
    SIGHT_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLocationType(self) -> int: ...
    def getPeerBluetoothAddress(self) -> str: ...
    def getRangingUpdateRate(self) -> int: ...
    def getSecurityLevel(self) -> int: ...
    def getSightType(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, peerBluetoothAddress: str | java.lang.String, /) -> None: ...
        def build(self) -> BleCsRangingParams: ...
        def setLocationType(self, locationType: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
        def setRangingUpdateRate(self, updateRate: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
        def setSecurityLevel(self, securityLevel: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
        def setSightType(self, sightType: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.net
import java.nio.channels
import java.nio.charset
import java.nio.file.attribute
import java.nio.file.spi
import java.security
import java.util
import java.util.concurrent
import java.util.function
import java.util.stream

class AccessDeniedException(FileSystemException):
    @typing.overload
    def __init__(self, file: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: str | java.lang.String, other: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...

class AccessMode(java.lang.Enum[AccessMode]):
    EXECUTE: typing.ClassVar[AccessMode] = ...
    READ: typing.ClassVar[AccessMode] = ...
    WRITE: typing.ClassVar[AccessMode] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> AccessMode: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[AccessMode]: ...

class AtomicMoveNotSupportedException(FileSystemException):
    def __init__(self, source: str | java.lang.String, target: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...

class ClosedDirectoryStreamException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class ClosedFileSystemException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class ClosedWatchServiceException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class CopyOption(java.lang.Object): ...

class DirectoryIteratorException(java.util.ConcurrentModificationException):
    def __init__(self, cause: java.io.IOException, /) -> None: ...
    def getCause(self) -> java.io.IOException: ...

class DirectoryNotEmptyException(FileSystemException):
    def __init__(self, dir: str | java.lang.String, /) -> None: ...

_DirectoryStream__T = typing.TypeVar('_DirectoryStream__T')  # <T>

_DirectoryStream__Filter__T = typing.TypeVar('_DirectoryStream__Filter__T')  # <T>
class DirectoryStream(java.io.Closeable, java.lang.Iterable[_DirectoryStream__T], typing.Generic[_DirectoryStream__T]):
    def iterator(self) -> java.util.Iterator[_DirectoryStream__T]: ...
    class Filter(java.lang.Object, typing.Generic[_DirectoryStream__Filter__T]):
        def accept(self, arg1: _DirectoryStream__Filter__T, /) -> bool: ...

class FileAlreadyExistsException(FileSystemException):
    @typing.overload
    def __init__(self, file: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: str | java.lang.String, other: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...

class FileStore(java.lang.Object):
    def __init__(self) -> None: ...
    def getAttribute(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getBlockSize(self) -> int: ...
    _getFileStoreAttributeView__V = typing.TypeVar('_getFileStoreAttributeView__V')  # <V>
    def getFileStoreAttributeView(self, arg1: typing.Type[_getFileStoreAttributeView__V], /) -> _getFileStoreAttributeView__V: ...
    def getTotalSpace(self) -> int: ...
    def getUnallocatedSpace(self) -> int: ...
    def getUsableSpace(self) -> int: ...
    def isReadOnly(self) -> bool: ...
    def name(self) -> str: ...
    @typing.overload
    def supportsFileAttributeView(self, arg1: typing.Type[java.nio.file.attribute.FileAttributeView], /) -> bool: ...
    @typing.overload
    def supportsFileAttributeView(self, arg1: str | java.lang.String, /) -> bool: ...
    def type(self) -> str: ...

class FileSystem(java.io.Closeable):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def getFileStores(self) -> java.lang.Iterable[FileStore]: ...
    def getPath(self, arg1: str | java.lang.String, /, *arg2: java.lang.String) -> Path: ...
    def getPathMatcher(self, arg1: str | java.lang.String, /) -> PathMatcher: ...
    def getRootDirectories(self) -> java.lang.Iterable[Path]: ...
    def getSeparator(self) -> str: ...
    def getUserPrincipalLookupService(self) -> java.nio.file.attribute.UserPrincipalLookupService: ...
    def isOpen(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def newWatchService(self) -> WatchService: ...
    def provider(self) -> java.nio.file.spi.FileSystemProvider: ...
    def supportedFileAttributeViews(self) -> java.util.Set[java.lang.String]: ...

class FileSystemAlreadyExistsException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class FileSystemException(java.io.IOException):
    @typing.overload
    def __init__(self, file: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: str | java.lang.String, other: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...
    def getFile(self) -> str: ...
    def getMessage(self) -> str: ...
    def getOtherFile(self) -> str: ...
    def getReason(self) -> str: ...

class FileSystemLoopException(FileSystemException):
    def __init__(self, file: str | java.lang.String, /) -> None: ...

class FileSystemNotFoundException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class FileSystems(java.lang.Object):
    @staticmethod
    def getDefault() -> FileSystem: ...
    @staticmethod
    def getFileSystem(uri: java.net.URI, /) -> FileSystem: ...
    @typing.overload
    @staticmethod
    def newFileSystem(uri: java.net.URI, env: java.util.Map[java.lang.String, java.lang.Object], /) -> FileSystem: ...
    @typing.overload
    @staticmethod
    def newFileSystem(path: Path, loader: java.lang.ClassLoader, /) -> FileSystem: ...
    @typing.overload
    @staticmethod
    def newFileSystem(uri: java.net.URI, env: java.util.Map[java.lang.String, java.lang.Object], loader: java.lang.ClassLoader, /) -> FileSystem: ...

class FileVisitOption(java.lang.Enum[FileVisitOption]):
    FOLLOW_LINKS: typing.ClassVar[FileVisitOption] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> FileVisitOption: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[FileVisitOption]: ...

class FileVisitResult(java.lang.Enum[FileVisitResult]):
    CONTINUE: typing.ClassVar[FileVisitResult] = ...
    SKIP_SIBLINGS: typing.ClassVar[FileVisitResult] = ...
    SKIP_SUBTREE: typing.ClassVar[FileVisitResult] = ...
    TERMINATE: typing.ClassVar[FileVisitResult] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> FileVisitResult: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[FileVisitResult]: ...

_FileVisitor__T = typing.TypeVar('_FileVisitor__T')  # <T>
class FileVisitor(java.lang.Object, typing.Generic[_FileVisitor__T]):
    def postVisitDirectory(self, arg1: _FileVisitor__T, arg2: java.io.IOException, /) -> FileVisitResult: ...
    def preVisitDirectory(self, arg1: _FileVisitor__T, arg2: java.nio.file.attribute.BasicFileAttributes, /) -> FileVisitResult: ...
    def visitFile(self, arg1: _FileVisitor__T, arg2: java.nio.file.attribute.BasicFileAttributes, /) -> FileVisitResult: ...
    def visitFileFailed(self, arg1: _FileVisitor__T, arg2: java.io.IOException, /) -> FileVisitResult: ...

class Files(java.lang.Object):
    @typing.overload
    @staticmethod
    def copy(source: Path, out: java.io.OutputStream, /) -> int: ...
    @typing.overload
    @staticmethod
    def copy(in_: java.io.InputStream, target: Path, /, *options: CopyOption) -> int: ...
    @typing.overload
    @staticmethod
    def copy(source: Path, target: Path, /, *options: CopyOption) -> Path: ...
    @staticmethod
    def createDirectories(dir: Path, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @staticmethod
    def createDirectory(dir: Path, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @staticmethod
    def createFile(path: Path, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @staticmethod
    def createLink(link: Path, existing: Path, /) -> Path: ...
    @staticmethod
    def createSymbolicLink(link: Path, target: Path, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @typing.overload
    @staticmethod
    def createTempDirectory(prefix: str | java.lang.String, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @typing.overload
    @staticmethod
    def createTempDirectory(dir: Path, prefix: str | java.lang.String, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @typing.overload
    @staticmethod
    def createTempFile(prefix: str | java.lang.String, suffix: str | java.lang.String, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @typing.overload
    @staticmethod
    def createTempFile(dir: Path, prefix: str | java.lang.String, suffix: str | java.lang.String, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> Path: ...
    @staticmethod
    def delete(path: Path, /) -> None: ...
    @staticmethod
    def deleteIfExists(path: Path, /) -> bool: ...
    @staticmethod
    def exists(path: Path, /, *options: LinkOption) -> bool: ...
    @staticmethod
    def find(start: Path, maxDepth: int | java.jint | java.lang.Integer, matcher: java.util.function.BiPredicate[Path, java.nio.file.attribute.BasicFileAttributes], /, *options: FileVisitOption) -> java.util.stream.Stream[Path]: ...
    @staticmethod
    def getAttribute(path: Path, attribute: str | java.lang.String, /, *options: LinkOption) -> java.lang.Object: ...
    _getFileAttributeView__V = typing.TypeVar('_getFileAttributeView__V')  # <V>
    @staticmethod
    def getFileAttributeView(path: Path, type: typing.Type[_getFileAttributeView__V], /, *options: LinkOption) -> _getFileAttributeView__V: ...
    @staticmethod
    def getFileStore(path: Path, /) -> FileStore: ...
    @staticmethod
    def getLastModifiedTime(path: Path, /, *options: LinkOption) -> java.nio.file.attribute.FileTime: ...
    @staticmethod
    def getOwner(path: Path, /, *options: LinkOption) -> java.nio.file.attribute.UserPrincipal: ...
    @staticmethod
    def getPosixFilePermissions(path: Path, /, *options: LinkOption) -> java.util.Set[java.nio.file.attribute.PosixFilePermission]: ...
    @staticmethod
    def isDirectory(path: Path, /, *options: LinkOption) -> bool: ...
    @staticmethod
    def isExecutable(path: Path, /) -> bool: ...
    @staticmethod
    def isHidden(path: Path, /) -> bool: ...
    @staticmethod
    def isReadable(path: Path, /) -> bool: ...
    @staticmethod
    def isRegularFile(path: Path, /, *options: LinkOption) -> bool: ...
    @staticmethod
    def isSameFile(path: Path, path2: Path, /) -> bool: ...
    @staticmethod
    def isSymbolicLink(path: Path, /) -> bool: ...
    @staticmethod
    def isWritable(path: Path, /) -> bool: ...
    @typing.overload
    @staticmethod
    def lines(path: Path, /) -> java.util.stream.Stream[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def lines(path: Path, cs: java.nio.charset.Charset, /) -> java.util.stream.Stream[java.lang.String]: ...
    @staticmethod
    def list(dir: Path, /) -> java.util.stream.Stream[Path]: ...
    @staticmethod
    def move(source: Path, target: Path, /, *options: CopyOption) -> Path: ...
    @typing.overload
    @staticmethod
    def newBufferedReader(path: Path, /) -> java.io.BufferedReader: ...
    @typing.overload
    @staticmethod
    def newBufferedReader(path: Path, cs: java.nio.charset.Charset, /) -> java.io.BufferedReader: ...
    @typing.overload
    @staticmethod
    def newBufferedWriter(path: Path, /, *options: OpenOption) -> java.io.BufferedWriter: ...
    @typing.overload
    @staticmethod
    def newBufferedWriter(path: Path, cs: java.nio.charset.Charset, /, *options: OpenOption) -> java.io.BufferedWriter: ...
    @typing.overload
    @staticmethod
    def newByteChannel(path: Path, /, *options: OpenOption) -> java.nio.channels.SeekableByteChannel: ...
    @typing.overload
    @staticmethod
    def newByteChannel(path: Path, options: java.util.Set[OpenOption], /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> java.nio.channels.SeekableByteChannel: ...
    @typing.overload
    @staticmethod
    def newDirectoryStream(dir: Path, /) -> DirectoryStream[Path]: ...
    @typing.overload
    @staticmethod
    def newDirectoryStream(dir: Path, glob: str | java.lang.String, /) -> DirectoryStream[Path]: ...
    @typing.overload
    @staticmethod
    def newDirectoryStream(dir: Path, filter: DirectoryStream.Filter[Path], /) -> DirectoryStream[Path]: ...
    @staticmethod
    def newInputStream(path: Path, /, *options: OpenOption) -> java.io.InputStream: ...
    @staticmethod
    def newOutputStream(path: Path, /, *options: OpenOption) -> java.io.OutputStream: ...
    @staticmethod
    def notExists(path: Path, /, *options: LinkOption) -> bool: ...
    @staticmethod
    def probeContentType(path: Path, /) -> str: ...
    @staticmethod
    def readAllBytes(path: Path, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    @staticmethod
    def readAllLines(path: Path, /) -> java.util.List[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def readAllLines(path: Path, cs: java.nio.charset.Charset, /) -> java.util.List[java.lang.String]: ...
    _readAttributes_0__A = typing.TypeVar('_readAttributes_0__A')  # <A>
    @typing.overload
    @staticmethod
    def readAttributes(path: Path, type: typing.Type[_readAttributes_0__A], /, *options: LinkOption) -> _readAttributes_0__A: ...
    @typing.overload
    @staticmethod
    def readAttributes(path: Path, attributes: str | java.lang.String, /, *options: LinkOption) -> java.util.Map[java.lang.String, java.lang.Object]: ...
    @staticmethod
    def readSymbolicLink(link: Path, /) -> Path: ...
    @staticmethod
    def setAttribute(path: Path, attribute: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /, *options: LinkOption) -> Path: ...
    @staticmethod
    def setLastModifiedTime(path: Path, time: java.nio.file.attribute.FileTime, /) -> Path: ...
    @staticmethod
    def setOwner(path: Path, owner: java.nio.file.attribute.UserPrincipal, /) -> Path: ...
    @staticmethod
    def setPosixFilePermissions(path: Path, perms: java.util.Set[java.nio.file.attribute.PosixFilePermission], /) -> Path: ...
    @staticmethod
    def size(path: Path, /) -> int: ...
    @typing.overload
    @staticmethod
    def walk(start: Path, /, *options: FileVisitOption) -> java.util.stream.Stream[Path]: ...
    @typing.overload
    @staticmethod
    def walk(start: Path, maxDepth: int | java.jint | java.lang.Integer, /, *options: FileVisitOption) -> java.util.stream.Stream[Path]: ...
    @typing.overload
    @staticmethod
    def walkFileTree(start: Path, visitor: FileVisitor[Path], /) -> Path: ...
    @typing.overload
    @staticmethod
    def walkFileTree(start: Path, options: java.util.Set[FileVisitOption], maxDepth: int | java.jint | java.lang.Integer, visitor: FileVisitor[Path], /) -> Path: ...
    @typing.overload
    @staticmethod
    def write(path: Path, lines: java.lang.Iterable[java.lang.CharSequence], /, *options: OpenOption) -> Path: ...
    @typing.overload
    @staticmethod
    def write(path: Path, bytes: java.chaquopy.JavaArrayJByte, /, *options: OpenOption) -> Path: ...
    @typing.overload
    @staticmethod
    def write(path: Path, lines: java.lang.Iterable[java.lang.CharSequence], cs: java.nio.charset.Charset, /, *options: OpenOption) -> Path: ...

class InvalidPathException(java.lang.IllegalArgumentException):
    @typing.overload
    def __init__(self, input: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, input: str | java.lang.String, reason: str | java.lang.String, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def getIndex(self) -> int: ...
    def getInput(self) -> str: ...
    def getMessage(self) -> str: ...
    def getReason(self) -> str: ...

class LinkOption(java.lang.Enum[LinkOption], CopyOption, OpenOption):
    NOFOLLOW_LINKS: typing.ClassVar[LinkOption] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> LinkOption: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[LinkOption]: ...

class LinkPermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...

class NoSuchFileException(FileSystemException):
    @typing.overload
    def __init__(self, file: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: str | java.lang.String, other: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...

class NotDirectoryException(FileSystemException):
    def __init__(self, file: str | java.lang.String, /) -> None: ...

class NotLinkException(FileSystemException):
    @typing.overload
    def __init__(self, file: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: str | java.lang.String, other: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...

class OpenOption(java.lang.Object): ...

class Path(Watchable, java.lang.Comparable[Path], java.lang.Iterable[Path]):
    def compareTo(self, arg1: Path, /) -> int: ...
    @typing.overload
    def endsWith(self, arg1: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def endsWith(self, arg1: Path, /) -> bool: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFileName(self) -> Path: ...
    def getFileSystem(self) -> FileSystem: ...
    def getName(self, arg1: int | java.jint | java.lang.Integer, /) -> Path: ...
    def getNameCount(self) -> int: ...
    def getParent(self) -> Path: ...
    def getRoot(self) -> Path: ...
    def hashCode(self) -> int: ...
    def isAbsolute(self) -> bool: ...
    def iterator(self) -> java.util.Iterator[Path]: ...
    def normalize(self) -> Path: ...
    @typing.overload
    @staticmethod
    def of(uri: java.net.URI, /) -> Path: ...
    @typing.overload
    @staticmethod
    def of(first: str | java.lang.String, /, *more: java.lang.String) -> Path: ...
    @typing.overload
    def register(self, arg1: WatchService, /, *arg2: WatchEvent.Kind[java.lang.Object]) -> WatchKey: ...
    @typing.overload
    def register(self, arg1: WatchService, arg2: java.chaquopy.JavaArray[WatchEvent.Kind[java.lang.Object]], /, *arg3: WatchEvent.Modifier) -> WatchKey: ...
    def relativize(self, arg1: Path, /) -> Path: ...
    @typing.overload
    def resolve(self, arg1: str | java.lang.String, /) -> Path: ...
    @typing.overload
    def resolve(self, arg1: Path, /) -> Path: ...
    @typing.overload
    def resolveSibling(self, arg1: str | java.lang.String, /) -> Path: ...
    @typing.overload
    def resolveSibling(self, arg1: Path, /) -> Path: ...
    @typing.overload
    def startsWith(self, arg1: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def startsWith(self, arg1: Path, /) -> bool: ...
    def subpath(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> Path: ...
    def toAbsolutePath(self) -> Path: ...
    def toFile(self) -> java.io.File: ...
    def toRealPath(self, *arg1: LinkOption) -> Path: ...
    def toString(self) -> str: ...
    def toUri(self) -> java.net.URI: ...

class PathMatcher(java.lang.Object):
    def matches(self, arg1: Path, /) -> bool: ...

class Paths(java.lang.Object):
    @typing.overload
    @staticmethod
    def get(uri: java.net.URI, /) -> Path: ...
    @typing.overload
    @staticmethod
    def get(first: str | java.lang.String, /, *more: java.lang.String) -> Path: ...

class ProviderMismatchException(java.lang.IllegalArgumentException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class ProviderNotFoundException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class ReadOnlyFileSystemException(java.lang.UnsupportedOperationException):
    def __init__(self) -> None: ...

_SecureDirectoryStream__T = typing.TypeVar('_SecureDirectoryStream__T')  # <T>
class SecureDirectoryStream(DirectoryStream[_SecureDirectoryStream__T], typing.Generic[_SecureDirectoryStream__T]):
    def deleteDirectory(self, arg1: _SecureDirectoryStream__T, /) -> None: ...
    def deleteFile(self, arg1: _SecureDirectoryStream__T, /) -> None: ...
    _getFileAttributeView_0__V = typing.TypeVar('_getFileAttributeView_0__V')  # <V>
    _getFileAttributeView_1__V = typing.TypeVar('_getFileAttributeView_1__V')  # <V>
    @typing.overload
    def getFileAttributeView(self, arg1: typing.Type[_getFileAttributeView_0__V], /) -> _getFileAttributeView_0__V: ...
    @typing.overload
    def getFileAttributeView(self, arg1: _SecureDirectoryStream__T, arg2: typing.Type[_getFileAttributeView_1__V], /, *arg3: LinkOption) -> _getFileAttributeView_1__V: ...
    def move(self, arg1: _SecureDirectoryStream__T, arg2: SecureDirectoryStream[_SecureDirectoryStream__T], arg3: _SecureDirectoryStream__T, /) -> None: ...
    def newByteChannel(self, arg1: _SecureDirectoryStream__T, arg2: java.util.Set[OpenOption], /, *arg3: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> java.nio.channels.SeekableByteChannel: ...
    def newDirectoryStream(self, arg1: _SecureDirectoryStream__T, /, *arg2: LinkOption) -> SecureDirectoryStream[_SecureDirectoryStream__T]: ...

_SimpleFileVisitor__T = typing.TypeVar('_SimpleFileVisitor__T')  # <T>
class SimpleFileVisitor(FileVisitor[_SimpleFileVisitor__T], typing.Generic[_SimpleFileVisitor__T]):
    def __init__(self) -> None: ...
    def postVisitDirectory(self, dir: _SimpleFileVisitor__T, exc: java.io.IOException, /) -> FileVisitResult: ...
    def preVisitDirectory(self, dir: _SimpleFileVisitor__T, attrs: java.nio.file.attribute.BasicFileAttributes, /) -> FileVisitResult: ...
    def visitFile(self, file: _SimpleFileVisitor__T, attrs: java.nio.file.attribute.BasicFileAttributes, /) -> FileVisitResult: ...
    def visitFileFailed(self, file: _SimpleFileVisitor__T, exc: java.io.IOException, /) -> FileVisitResult: ...

class StandardCopyOption(java.lang.Enum[StandardCopyOption], CopyOption):
    ATOMIC_MOVE: typing.ClassVar[StandardCopyOption] = ...
    COPY_ATTRIBUTES: typing.ClassVar[StandardCopyOption] = ...
    REPLACE_EXISTING: typing.ClassVar[StandardCopyOption] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> StandardCopyOption: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[StandardCopyOption]: ...

class StandardOpenOption(java.lang.Enum[StandardOpenOption], OpenOption):
    APPEND: typing.ClassVar[StandardOpenOption] = ...
    CREATE: typing.ClassVar[StandardOpenOption] = ...
    CREATE_NEW: typing.ClassVar[StandardOpenOption] = ...
    DELETE_ON_CLOSE: typing.ClassVar[StandardOpenOption] = ...
    DSYNC: typing.ClassVar[StandardOpenOption] = ...
    READ: typing.ClassVar[StandardOpenOption] = ...
    SPARSE: typing.ClassVar[StandardOpenOption] = ...
    SYNC: typing.ClassVar[StandardOpenOption] = ...
    TRUNCATE_EXISTING: typing.ClassVar[StandardOpenOption] = ...
    WRITE: typing.ClassVar[StandardOpenOption] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> StandardOpenOption: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[StandardOpenOption]: ...

class StandardWatchEventKinds(java.lang.Object):
    ENTRY_CREATE: typing.ClassVar[WatchEvent.Kind[Path]] = ...
    ENTRY_DELETE: typing.ClassVar[WatchEvent.Kind[Path]] = ...
    ENTRY_MODIFY: typing.ClassVar[WatchEvent.Kind[Path]] = ...
    OVERFLOW: typing.ClassVar[WatchEvent.Kind[java.lang.Object]] = ...

_WatchEvent__T = typing.TypeVar('_WatchEvent__T')  # <T>

_WatchEvent__Kind__T = typing.TypeVar('_WatchEvent__Kind__T')  # <T>
class WatchEvent(java.lang.Object, typing.Generic[_WatchEvent__T]):
    def context(self) -> _WatchEvent__T: ...
    def count(self) -> int: ...
    def kind(self) -> WatchEvent.Kind[_WatchEvent__T]: ...

    class Modifier(java.lang.Object):
        def name(self) -> str: ...
    class Kind(java.lang.Object, typing.Generic[_WatchEvent__Kind__T]):
        def name(self) -> str: ...
        def type(self) -> typing.Type[_WatchEvent__Kind__T]: ...

class WatchKey(java.lang.Object):
    def cancel(self) -> None: ...
    def isValid(self) -> bool: ...
    def pollEvents(self) -> java.util.List[WatchEvent[java.lang.Object]]: ...
    def reset(self) -> bool: ...
    def watchable(self) -> Watchable: ...

class WatchService(java.io.Closeable):
    def close(self) -> None: ...
    @typing.overload
    def poll(self) -> WatchKey: ...
    @typing.overload
    def poll(self, arg1: int | java.jlong | java.lang.Long, arg2: java.util.concurrent.TimeUnit, /) -> WatchKey: ...
    def take(self) -> WatchKey: ...

class Watchable(java.lang.Object):
    @typing.overload
    def register(self, arg1: WatchService, /, *arg2: WatchEvent.Kind[java.lang.Object]) -> WatchKey: ...
    @typing.overload
    def register(self, arg1: WatchService, arg2: java.chaquopy.JavaArray[WatchEvent.Kind[java.lang.Object]], /, *arg3: WatchEvent.Modifier) -> WatchKey: ...



import typing

import android.os
import java
import java.lang
import java.util

class DocumentChangeInfo(java.lang.Object):
    def __init__(self, packageName: str | java.lang.String, database: str | java.lang.String, namespace: str | java.lang.String, schemaName: str | java.lang.String, changedDocumentIds: java.util.Set[java.lang.String], /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChangedDocumentIds(self) -> java.util.Set[java.lang.String]: ...
    def getDatabaseName(self) -> str: ...
    def getNamespace(self) -> str: ...
    def getPackageName(self) -> str: ...
    def getSchemaName(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class ObserverCallback(java.lang.Object):
    def onDocumentChanged(self, arg1: DocumentChangeInfo, /) -> None: ...
    def onSchemaChanged(self, arg1: SchemaChangeInfo, /) -> None: ...

class ObserverSpec(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ObserverSpec]] = ...
    def describeContents(self) -> int: ...
    def getFilterSchemas(self) -> java.util.Set[java.lang.String]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        @typing.overload
        def addFilterSchemas(self, schemas: java.util.Collection[java.lang.String], /) -> ObserverSpec.Builder: ...
        @typing.overload
        def addFilterSchemas(self, *schemas: java.lang.String) -> ObserverSpec.Builder: ...
        def build(self) -> ObserverSpec: ...

class SchemaChangeInfo(java.lang.Object):
    def __init__(self, packageName: str | java.lang.String, databaseName: str | java.lang.String, changedSchemaNames: java.util.Set[java.lang.String], /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChangedSchemaNames(self) -> java.util.Set[java.lang.String]: ...
    def getDatabaseName(self) -> str: ...
    def getPackageName(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...



import typing

import java
import java.io
import java.lang
import java.util

class ErrorListener(java.lang.Object):
    def error(self, arg1: TransformerException, /) -> None: ...
    def fatalError(self, arg1: TransformerException, /) -> None: ...
    def warning(self, arg1: TransformerException, /) -> None: ...

class OutputKeys(java.lang.Object):
    CDATA_SECTION_ELEMENTS: typing.ClassVar[str] = ...
    DOCTYPE_PUBLIC: typing.ClassVar[str] = ...
    DOCTYPE_SYSTEM: typing.ClassVar[str] = ...
    ENCODING: typing.ClassVar[str] = ...
    INDENT: typing.ClassVar[str] = ...
    MEDIA_TYPE: typing.ClassVar[str] = ...
    METHOD: typing.ClassVar[str] = ...
    OMIT_XML_DECLARATION: typing.ClassVar[str] = ...
    STANDALONE: typing.ClassVar[str] = ...
    VERSION: typing.ClassVar[str] = ...

class Result(java.lang.Object):
    PI_DISABLE_OUTPUT_ESCAPING: typing.ClassVar[str] = ...
    PI_ENABLE_OUTPUT_ESCAPING: typing.ClassVar[str] = ...
    def getSystemId(self) -> str: ...
    def setSystemId(self, arg1: str | java.lang.String, /) -> None: ...

class Source(java.lang.Object):
    def getSystemId(self) -> str: ...
    def setSystemId(self, arg1: str | java.lang.String, /) -> None: ...

class SourceLocator(java.lang.Object):
    def getColumnNumber(self) -> int: ...
    def getLineNumber(self) -> int: ...
    def getPublicId(self) -> str: ...
    def getSystemId(self) -> str: ...

class Templates(java.lang.Object):
    def getOutputProperties(self) -> java.util.Properties: ...
    def newTransformer(self) -> Transformer: ...

class Transformer(java.lang.Object):
    def __init__(self) -> None: ...
    def clearParameters(self) -> None: ...
    def getErrorListener(self) -> ErrorListener: ...
    def getOutputProperties(self) -> java.util.Properties: ...
    def getOutputProperty(self, arg1: str | java.lang.String, /) -> str: ...
    def getParameter(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getURIResolver(self) -> URIResolver: ...
    def reset(self) -> None: ...
    def setErrorListener(self, arg1: ErrorListener, /) -> None: ...
    def setOutputProperties(self, arg1: java.util.Properties, /) -> None: ...
    def setOutputProperty(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def setParameter(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setURIResolver(self, arg1: URIResolver, /) -> None: ...
    def transform(self, arg1: Source, arg2: Result, /) -> None: ...

class TransformerConfigurationException(TransformerException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, e: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, e: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, locator: SourceLocator, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, locator: SourceLocator, e: java.lang.Throwable, /) -> None: ...

class TransformerException(java.lang.Exception):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, e: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, e: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, locator: SourceLocator, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, locator: SourceLocator, e: java.lang.Throwable, /) -> None: ...
    def getCause(self) -> java.lang.Throwable: ...
    def getException(self) -> java.lang.Throwable: ...
    def getLocationAsString(self) -> str: ...
    def getLocator(self) -> SourceLocator: ...
    def getMessageAndLocation(self) -> str: ...
    def initCause(self, cause: java.lang.Throwable, /) -> java.lang.Throwable: ...
    @typing.overload
    def printStackTrace(self) -> None: ...
    @typing.overload
    def printStackTrace(self, s: java.io.PrintStream, /) -> None: ...
    @typing.overload
    def printStackTrace(self, s: java.io.PrintWriter, /) -> None: ...
    def setLocator(self, location: SourceLocator, /) -> None: ...

class TransformerFactory(java.lang.Object):
    def __init__(self) -> None: ...
    def getAssociatedStylesheet(self, arg1: Source, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: str | java.lang.String, /) -> Source: ...
    def getAttribute(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getErrorListener(self) -> ErrorListener: ...
    def getFeature(self, arg1: str | java.lang.String, /) -> bool: ...
    def getURIResolver(self) -> URIResolver: ...
    @typing.overload
    @staticmethod
    def newInstance() -> TransformerFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(factoryClassName: str | java.lang.String, classLoader: java.lang.ClassLoader, /) -> TransformerFactory: ...
    def newTemplates(self, arg1: Source, /) -> Templates: ...
    @typing.overload
    def newTransformer(self) -> Transformer: ...
    @typing.overload
    def newTransformer(self, arg1: Source, /) -> Transformer: ...
    def setAttribute(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setErrorListener(self, arg1: ErrorListener, /) -> None: ...
    def setFeature(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setURIResolver(self, arg1: URIResolver, /) -> None: ...

class TransformerFactoryConfigurationError(java.lang.Error):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, e: java.lang.Exception, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, e: java.lang.Exception, msg: str | java.lang.String, /) -> None: ...
    def getException(self) -> java.lang.Exception: ...
    def getMessage(self) -> str: ...

class URIResolver(java.lang.Object):
    def resolve(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> Source: ...



import typing

import android.app
import android.content
import android.media
import android.net
import android.os
import android.view
import java
import java.lang
import java.util
import java.util.concurrent

class MediaController(java.lang.Object):
    def __init__(self, context: android.content.Context, token: MediaSession.Token, /) -> None: ...
    def adjustVolume(self, direction: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchMediaButtonEvent(self, keyEvent: android.view.KeyEvent, /) -> bool: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getFlags(self) -> int: ...
    def getMetadata(self) -> android.media.MediaMetadata | None: ...
    def getPackageName(self) -> str: ...
    def getPlaybackInfo(self) -> MediaController.PlaybackInfo: ...
    def getPlaybackState(self) -> PlaybackState | None: ...
    def getQueue(self) -> java.util.List[MediaSession.QueueItem] | None: ...
    def getQueueTitle(self) -> java.lang.CharSequence | None: ...
    def getRatingType(self) -> int: ...
    def getSessionActivity(self) -> android.app.PendingIntent | None: ...
    def getSessionInfo(self) -> android.os.Bundle: ...
    def getSessionToken(self) -> MediaSession.Token: ...
    def getTag(self) -> str: ...
    def getTransportControls(self) -> MediaController.TransportControls: ...
    @typing.overload
    def registerCallback(self, callback: MediaController.Callback, /) -> None: ...
    @typing.overload
    def registerCallback(self, callback: MediaController.Callback, handler: android.os.Handler, /) -> None: ...
    def sendCommand(self, command: str | java.lang.String, args: android.os.Bundle, cb: android.os.ResultReceiver, /) -> None: ...
    def setVolumeTo(self, value: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def unregisterCallback(self, callback: MediaController.Callback, /) -> None: ...

    class TransportControls(java.lang.Object):
        def fastForward(self) -> None: ...
        def pause(self) -> None: ...
        def play(self) -> None: ...
        def playFromMediaId(self, mediaId: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def playFromSearch(self, query: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def playFromUri(self, uri: android.net.Uri, extras: android.os.Bundle, /) -> None: ...
        def prepare(self) -> None: ...
        def prepareFromMediaId(self, mediaId: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def prepareFromSearch(self, query: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def prepareFromUri(self, uri: android.net.Uri, extras: android.os.Bundle, /) -> None: ...
        def rewind(self) -> None: ...
        def seekTo(self, pos: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def sendCustomAction(self, customAction: PlaybackState.CustomAction, args: android.os.Bundle, /) -> None: ...
        @typing.overload
        def sendCustomAction(self, action: str | java.lang.String, args: android.os.Bundle, /) -> None: ...
        def setPlaybackSpeed(self, speed: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setRating(self, rating: android.media.Rating, /) -> None: ...
        def skipToNext(self) -> None: ...
        def skipToPrevious(self) -> None: ...
        def skipToQueueItem(self, id: int | java.jlong | java.lang.Long, /) -> None: ...
        def stop(self) -> None: ...

    class PlaybackInfo(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MediaController.PlaybackInfo]] = ...
        PLAYBACK_TYPE_LOCAL: typing.ClassVar[int] = ...
        PLAYBACK_TYPE_REMOTE: typing.ClassVar[int] = ...
        def describeContents(self) -> int: ...
        def getAudioAttributes(self) -> android.media.AudioAttributes: ...
        def getCurrentVolume(self) -> int: ...
        def getMaxVolume(self) -> int: ...
        def getPlaybackType(self) -> int: ...
        def getVolumeControl(self) -> int: ...
        def getVolumeControlId(self) -> str: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAudioInfoChanged(self, playbackInfo: MediaController.PlaybackInfo, /) -> None: ...
        def onExtrasChanged(self, extras: android.os.Bundle, /) -> None: ...
        def onMetadataChanged(self, metadata: android.media.MediaMetadata, /) -> None: ...
        def onPlaybackStateChanged(self, state: PlaybackState, /) -> None: ...
        def onQueueChanged(self, queue: java.util.List[MediaSession.QueueItem], /) -> None: ...
        def onQueueTitleChanged(self, title: java.lang.CharSequence, /) -> None: ...
        def onSessionDestroyed(self) -> None: ...
        def onSessionEvent(self, event: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...

class MediaSession(java.lang.Object):
    FLAG_HANDLES_MEDIA_BUTTONS: typing.ClassVar[int] = ...
    FLAG_HANDLES_TRANSPORT_CONTROLS: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, tag: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, tag: str | java.lang.String, sessionInfo: android.os.Bundle, /) -> None: ...
    def getController(self) -> MediaController: ...
    def getCurrentControllerInfo(self) -> MediaSessionManager.RemoteUserInfo: ...
    def getSessionToken(self) -> MediaSession.Token: ...
    def isActive(self) -> bool: ...
    def release(self) -> None: ...
    def sendSessionEvent(self, event: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
    def setActive(self, active: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setCallback(self, callback: MediaSession.Callback, /) -> None: ...
    @typing.overload
    def setCallback(self, callback: MediaSession.Callback, handler: android.os.Handler, /) -> None: ...
    def setExtras(self, extras: android.os.Bundle, /) -> None: ...
    def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMediaButtonBroadcastReceiver(self, broadcastReceiver: android.content.ComponentName, /) -> None: ...
    def setMediaButtonReceiver(self, mbr: android.app.PendingIntent, /) -> None: ...
    def setMetadata(self, metadata: android.media.MediaMetadata, /) -> None: ...
    def setPlaybackState(self, state: PlaybackState, /) -> None: ...
    def setPlaybackToLocal(self, attributes: android.media.AudioAttributes, /) -> None: ...
    def setPlaybackToRemote(self, volumeProvider: android.media.VolumeProvider, /) -> None: ...
    def setQueue(self, queue: java.util.List[MediaSession.QueueItem], /) -> None: ...
    def setQueueTitle(self, title: java.lang.CharSequence, /) -> None: ...
    def setRatingType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSessionActivity(self, pi: android.app.PendingIntent, /) -> None: ...

    class Token(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MediaSession.Token]] = ...
        def describeContents(self) -> int: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class QueueItem(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MediaSession.QueueItem]] = ...
        UNKNOWN_ID: typing.ClassVar[int] = ...
        def __init__(self, description: android.media.MediaDescription, id: int | java.jlong | java.lang.Long, /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getDescription(self) -> android.media.MediaDescription: ...
        def getQueueId(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onCommand(self, command: str | java.lang.String, args: android.os.Bundle, cb: android.os.ResultReceiver, /) -> None: ...
        def onCustomAction(self, action: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def onFastForward(self) -> None: ...
        def onMediaButtonEvent(self, mediaButtonIntent: android.content.Intent, /) -> bool: ...
        def onPause(self) -> None: ...
        def onPlay(self) -> None: ...
        def onPlayFromMediaId(self, mediaId: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def onPlayFromSearch(self, query: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def onPlayFromUri(self, uri: android.net.Uri, extras: android.os.Bundle, /) -> None: ...
        def onPrepare(self) -> None: ...
        def onPrepareFromMediaId(self, mediaId: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def onPrepareFromSearch(self, query: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def onPrepareFromUri(self, uri: android.net.Uri, extras: android.os.Bundle, /) -> None: ...
        def onRewind(self) -> None: ...
        def onSeekTo(self, pos: int | java.jlong | java.lang.Long, /) -> None: ...
        def onSetPlaybackSpeed(self, speed: float | java.jfloat | java.lang.Float, /) -> None: ...
        def onSetRating(self, rating: android.media.Rating, /) -> None: ...
        def onSkipToNext(self) -> None: ...
        def onSkipToPrevious(self) -> None: ...
        def onSkipToQueueItem(self, id: int | java.jlong | java.lang.Long, /) -> None: ...
        def onStop(self) -> None: ...

class MediaSessionManager(java.lang.Object):
    @typing.overload
    def addOnActiveSessionsChangedListener(self, sessionListener: MediaSessionManager.OnActiveSessionsChangedListener, notificationListener: android.content.ComponentName, /) -> None: ...
    @typing.overload
    def addOnActiveSessionsChangedListener(self, sessionListener: MediaSessionManager.OnActiveSessionsChangedListener, notificationListener: android.content.ComponentName, handler: android.os.Handler, /) -> None: ...
    def addOnMediaKeyEventSessionChangedListener(self, executor: java.util.concurrent.Executor, listener: MediaSessionManager.OnMediaKeyEventSessionChangedListener, /) -> None: ...
    @typing.overload
    def addOnSession2TokensChangedListener(self, listener: MediaSessionManager.OnSession2TokensChangedListener, /) -> None: ...
    @typing.overload
    def addOnSession2TokensChangedListener(self, listener: MediaSessionManager.OnSession2TokensChangedListener, handler: android.os.Handler, /) -> None: ...
    def getActiveSessions(self, notificationListener: android.content.ComponentName, /) -> java.util.List[MediaController]: ...
    def getMediaKeyEventSession(self) -> MediaSession.Token | None: ...
    def getMediaKeyEventSessionPackageName(self) -> str: ...
    def getSession2Tokens(self) -> java.util.List[android.media.Session2Token]: ...
    def isTrustedForMediaControl(self, userInfo: MediaSessionManager.RemoteUserInfo, /) -> bool: ...
    def notifySession2Created(self, token: android.media.Session2Token, /) -> None: ...
    def removeOnActiveSessionsChangedListener(self, sessionListener: MediaSessionManager.OnActiveSessionsChangedListener, /) -> None: ...
    def removeOnMediaKeyEventSessionChangedListener(self, listener: MediaSessionManager.OnMediaKeyEventSessionChangedListener, /) -> None: ...
    def removeOnSession2TokensChangedListener(self, listener: MediaSessionManager.OnSession2TokensChangedListener, /) -> None: ...

    class RemoteUserInfo(java.lang.Object):
        def __init__(self, packageName: str | java.lang.String, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getPackageName(self) -> str: ...
        def getPid(self) -> int: ...
        def getUid(self) -> int: ...
        def hashCode(self) -> int: ...

    class OnSession2TokensChangedListener(java.lang.Object):
        def onSession2TokensChanged(self, arg1: java.util.List[android.media.Session2Token], /) -> None: ...

    class OnMediaKeyEventSessionChangedListener(java.lang.Object):
        def onMediaKeyEventSessionChanged(self, arg1: str | java.lang.String, arg2: MediaSession.Token, /) -> None: ...

    class OnActiveSessionsChangedListener(java.lang.Object):
        def onActiveSessionsChanged(self, arg1: java.util.List[MediaController], /) -> None: ...

class PlaybackState(android.os.Parcelable):
    ACTION_FAST_FORWARD: typing.ClassVar[int] = ...
    ACTION_PAUSE: typing.ClassVar[int] = ...
    ACTION_PLAY: typing.ClassVar[int] = ...
    ACTION_PLAY_FROM_MEDIA_ID: typing.ClassVar[int] = ...
    ACTION_PLAY_FROM_SEARCH: typing.ClassVar[int] = ...
    ACTION_PLAY_FROM_URI: typing.ClassVar[int] = ...
    ACTION_PLAY_PAUSE: typing.ClassVar[int] = ...
    ACTION_PREPARE: typing.ClassVar[int] = ...
    ACTION_PREPARE_FROM_MEDIA_ID: typing.ClassVar[int] = ...
    ACTION_PREPARE_FROM_SEARCH: typing.ClassVar[int] = ...
    ACTION_PREPARE_FROM_URI: typing.ClassVar[int] = ...
    ACTION_REWIND: typing.ClassVar[int] = ...
    ACTION_SEEK_TO: typing.ClassVar[int] = ...
    ACTION_SET_PLAYBACK_SPEED: typing.ClassVar[int] = ...
    ACTION_SET_RATING: typing.ClassVar[int] = ...
    ACTION_SKIP_TO_NEXT: typing.ClassVar[int] = ...
    ACTION_SKIP_TO_PREVIOUS: typing.ClassVar[int] = ...
    ACTION_SKIP_TO_QUEUE_ITEM: typing.ClassVar[int] = ...
    ACTION_STOP: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PlaybackState]] = ...
    PLAYBACK_POSITION_UNKNOWN: typing.ClassVar[int] = ...
    STATE_BUFFERING: typing.ClassVar[int] = ...
    STATE_CONNECTING: typing.ClassVar[int] = ...
    STATE_ERROR: typing.ClassVar[int] = ...
    STATE_FAST_FORWARDING: typing.ClassVar[int] = ...
    STATE_NONE: typing.ClassVar[int] = ...
    STATE_PAUSED: typing.ClassVar[int] = ...
    STATE_PLAYING: typing.ClassVar[int] = ...
    STATE_REWINDING: typing.ClassVar[int] = ...
    STATE_SKIPPING_TO_NEXT: typing.ClassVar[int] = ...
    STATE_SKIPPING_TO_PREVIOUS: typing.ClassVar[int] = ...
    STATE_SKIPPING_TO_QUEUE_ITEM: typing.ClassVar[int] = ...
    STATE_STOPPED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getActions(self) -> int: ...
    def getActiveQueueItemId(self) -> int: ...
    def getBufferedPosition(self) -> int: ...
    def getCustomActions(self) -> java.util.List[PlaybackState.CustomAction]: ...
    def getErrorMessage(self) -> java.lang.CharSequence: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getLastPositionUpdateTime(self) -> int: ...
    def getPlaybackSpeed(self) -> float: ...
    def getPosition(self) -> int: ...
    def getState(self) -> int: ...
    def isActive(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class CustomAction(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PlaybackState.CustomAction]] = ...
        def describeContents(self) -> int: ...
        def getAction(self) -> str: ...
        def getExtras(self) -> android.os.Bundle: ...
        def getIcon(self) -> int: ...
        def getName(self) -> java.lang.CharSequence: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class Builder(java.lang.Object):
            def __init__(self, action: str | java.lang.String, name: java.lang.CharSequence, icon: int | java.jint | java.lang.Integer, /) -> None: ...
            def build(self) -> PlaybackState.CustomAction: ...
            def setExtras(self, extras: android.os.Bundle, /) -> PlaybackState.CustomAction.Builder: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, from_: PlaybackState, /) -> None: ...
        @typing.overload
        def addCustomAction(self, customAction: PlaybackState.CustomAction, /) -> PlaybackState.Builder: ...
        @typing.overload
        def addCustomAction(self, action: str | java.lang.String, name: str | java.lang.String, icon: int | java.jint | java.lang.Integer, /) -> PlaybackState.Builder: ...
        def build(self) -> PlaybackState: ...
        def setActions(self, actions: int | java.jlong | java.lang.Long, /) -> PlaybackState.Builder: ...
        def setActiveQueueItemId(self, id: int | java.jlong | java.lang.Long, /) -> PlaybackState.Builder: ...
        def setBufferedPosition(self, bufferedPosition: int | java.jlong | java.lang.Long, /) -> PlaybackState.Builder: ...
        def setErrorMessage(self, error: java.lang.CharSequence, /) -> PlaybackState.Builder: ...
        def setExtras(self, extras: android.os.Bundle, /) -> PlaybackState.Builder: ...
        @typing.overload
        def setState(self, state: int | java.jint | java.lang.Integer, position: int | java.jlong | java.lang.Long, playbackSpeed: float | java.jfloat | java.lang.Float, /) -> PlaybackState.Builder: ...
        @typing.overload
        def setState(self, state: int | java.jint | java.lang.Integer, position: int | java.jlong | java.lang.Long, playbackSpeed: float | java.jfloat | java.lang.Float, updateTime: int | java.jlong | java.lang.Long, /) -> PlaybackState.Builder: ...
